'''
extended_tablerqicon.pyi
--------------------------------------------------------------------------------
This file is generated by the `sync_tabler_icons.sh` script.
--------------------------------------------------------------------------------
NOTE: DO NOT EDIT THIS FILE DIRECTLY.
--------------------------------------------------------------------------------
This Python Interface (pyi) file provides an interface for the
ExtendedTablerQIcon class which extends from the TablerQIcon class.

The icons are cloned from the Tabler Icons GitHub repository
(https://github.com/tabler/tabler-icons/tree/master/icons) into the
local directory `tablerqicon/icons` as SVG files.

Each SVG file in this directory is reflected as an attribute in this file
that returns a QIcon object.

The `sync_tabler_icons.sh` script updates this file whenever the script is run,
to reflect any changes in the Tabler Icons repository.
--------------------------------------------------------------------------------
'''

from .tablerqicon import TablerQIcon

class QIcon: ...

class ExtendedTablerQIcon(TablerQIcon):
    _123: QIcon
    _12_hours: QIcon
    _24_hours: QIcon
    _2fa: QIcon
    _360: QIcon
    _360_view: QIcon
    _3d_cube_sphere: QIcon
    _3d_cube_sphere_off: QIcon
    _3d_rotate: QIcon
    a_b: QIcon
    a_b_2: QIcon
    abacus: QIcon
    abacus_off: QIcon
    abc: QIcon
    a_b_off: QIcon
    accessible: QIcon
    accessible_off: QIcon
    accessible_off_filled: QIcon
    access_point: QIcon
    access_point_off: QIcon
    activity: QIcon
    activity_heartbeat: QIcon
    ad: QIcon
    ad_2: QIcon
    ad_circle: QIcon
    ad_circle_filled: QIcon
    ad_circle_off: QIcon
    address_book: QIcon
    address_book_off: QIcon
    ad_filled: QIcon
    adjustments: QIcon
    adjustments_alt: QIcon
    adjustments_bolt: QIcon
    adjustments_cancel: QIcon
    adjustments_check: QIcon
    adjustments_code: QIcon
    adjustments_cog: QIcon
    adjustments_dollar: QIcon
    adjustments_down: QIcon
    adjustments_exclamation: QIcon
    adjustments_filled: QIcon
    adjustments_heart: QIcon
    adjustments_horizontal: QIcon
    adjustments_minus: QIcon
    adjustments_off: QIcon
    adjustments_pause: QIcon
    adjustments_pin: QIcon
    adjustments_plus: QIcon
    adjustments_question: QIcon
    adjustments_search: QIcon
    adjustments_share: QIcon
    adjustments_star: QIcon
    adjustments_up: QIcon
    adjustments_x: QIcon
    ad_off: QIcon
    aerial_lift: QIcon
    affiliate: QIcon
    affiliate_filled: QIcon
    air_balloon: QIcon
    air_conditioning: QIcon
    air_conditioning_disabled: QIcon
    air_traffic_control: QIcon
    alarm: QIcon
    alarm_filled: QIcon
    alarm_minus: QIcon
    alarm_minus_filled: QIcon
    alarm_off: QIcon
    alarm_plus: QIcon
    alarm_plus_filled: QIcon
    alarm_snooze: QIcon
    alarm_snooze_filled: QIcon
    album: QIcon
    album_off: QIcon
    alert_circle: QIcon
    alert_circle_filled: QIcon
    alert_circle_off: QIcon
    alert_hexagon: QIcon
    alert_hexagon_filled: QIcon
    alert_hexagon_off: QIcon
    alert_octagon: QIcon
    alert_octagon_filled: QIcon
    alert_small: QIcon
    alert_small_off: QIcon
    alert_square: QIcon
    alert_square_filled: QIcon
    alert_square_rounded: QIcon
    alert_square_rounded_filled: QIcon
    alert_square_rounded_off: QIcon
    alert_triangle: QIcon
    alert_triangle_filled: QIcon
    alert_triangle_off: QIcon
    alien: QIcon
    alien_filled: QIcon
    align_box_bottom_center: QIcon
    align_box_bottom_center_filled: QIcon
    align_box_bottom_left: QIcon
    align_box_bottom_left_filled: QIcon
    align_box_bottom_right: QIcon
    align_box_bottom_right_filled: QIcon
    align_box_center_bottom: QIcon
    align_box_center_middle: QIcon
    align_box_center_middle_filled: QIcon
    align_box_center_stretch: QIcon
    align_box_center_top: QIcon
    align_box_left_bottom: QIcon
    align_box_left_bottom_filled: QIcon
    align_box_left_middle: QIcon
    align_box_left_middle_filled: QIcon
    align_box_left_stretch: QIcon
    align_box_left_top: QIcon
    align_box_left_top_filled: QIcon
    align_box_right_bottom: QIcon
    align_box_right_bottom_filled: QIcon
    align_box_right_middle: QIcon
    align_box_right_middle_filled: QIcon
    align_box_right_stretch: QIcon
    align_box_right_top: QIcon
    align_box_right_top_filled: QIcon
    align_box_top_center: QIcon
    align_box_top_center_filled: QIcon
    align_box_top_left: QIcon
    align_box_top_left_filled: QIcon
    align_box_top_right: QIcon
    align_box_top_right_filled: QIcon
    align_center: QIcon
    align_justified: QIcon
    align_left: QIcon
    align_right: QIcon
    alpha: QIcon
    alphabet_cyrillic: QIcon
    alphabet_greek: QIcon
    alphabet_latin: QIcon
    alt: QIcon
    ambulance: QIcon
    ampersand: QIcon
    analyze: QIcon
    analyze_filled: QIcon
    analyze_off: QIcon
    anchor: QIcon
    anchor_off: QIcon
    angle: QIcon
    ankh: QIcon
    antenna: QIcon
    antenna_bars_1: QIcon
    antenna_bars_2: QIcon
    antenna_bars_3: QIcon
    antenna_bars_4: QIcon
    antenna_bars_5: QIcon
    antenna_bars_off: QIcon
    antenna_off: QIcon
    aperture: QIcon
    aperture_off: QIcon
    api: QIcon
    api_app: QIcon
    api_app_off: QIcon
    api_off: QIcon
    apple: QIcon
    apps: QIcon
    apps_filled: QIcon
    apps_off: QIcon
    app_window: QIcon
    app_window_filled: QIcon
    archery_arrow: QIcon
    archive: QIcon
    archive_filled: QIcon
    archive_off: QIcon
    armchair: QIcon
    armchair_2: QIcon
    armchair_2_off: QIcon
    armchair_off: QIcon
    arrow_autofit_content: QIcon
    arrow_autofit_content_filled: QIcon
    arrow_autofit_down: QIcon
    arrow_autofit_height: QIcon
    arrow_autofit_left: QIcon
    arrow_autofit_right: QIcon
    arrow_autofit_up: QIcon
    arrow_autofit_width: QIcon
    arrow_back: QIcon
    arrow_back_up: QIcon
    arrow_back_up_double: QIcon
    arrow_badge_down: QIcon
    arrow_badge_down_filled: QIcon
    arrow_badge_left: QIcon
    arrow_badge_left_filled: QIcon
    arrow_badge_right: QIcon
    arrow_badge_right_filled: QIcon
    arrow_badge_up: QIcon
    arrow_badge_up_filled: QIcon
    arrow_bar_both: QIcon
    arrow_bar_down: QIcon
    arrow_bar_left: QIcon
    arrow_bar_right: QIcon
    arrow_bar_to_down: QIcon
    arrow_bar_to_left: QIcon
    arrow_bar_to_right: QIcon
    arrow_bar_to_up: QIcon
    arrow_bar_up: QIcon
    arrow_bear_left: QIcon
    arrow_bear_left_2: QIcon
    arrow_bear_right: QIcon
    arrow_bear_right_2: QIcon
    arrow_big_down: QIcon
    arrow_big_down_filled: QIcon
    arrow_big_down_line: QIcon
    arrow_big_down_line_filled: QIcon
    arrow_big_down_lines: QIcon
    arrow_big_down_lines_filled: QIcon
    arrow_big_left: QIcon
    arrow_big_left_filled: QIcon
    arrow_big_left_line: QIcon
    arrow_big_left_line_filled: QIcon
    arrow_big_left_lines: QIcon
    arrow_big_left_lines_filled: QIcon
    arrow_big_right: QIcon
    arrow_big_right_filled: QIcon
    arrow_big_right_line: QIcon
    arrow_big_right_line_filled: QIcon
    arrow_big_right_lines: QIcon
    arrow_big_right_lines_filled: QIcon
    arrow_big_up: QIcon
    arrow_big_up_filled: QIcon
    arrow_big_up_line: QIcon
    arrow_big_up_line_filled: QIcon
    arrow_big_up_lines: QIcon
    arrow_big_up_lines_filled: QIcon
    arrow_bounce: QIcon
    arrow_capsule: QIcon
    arrow_curve_left: QIcon
    arrow_curve_right: QIcon
    arrow_down: QIcon
    arrow_down_bar: QIcon
    arrow_down_circle: QIcon
    arrow_down_left: QIcon
    arrow_down_left_circle: QIcon
    arrow_down_rhombus: QIcon
    arrow_down_right: QIcon
    arrow_down_right_circle: QIcon
    arrow_down_square: QIcon
    arrow_down_tail: QIcon
    arrow_elbow_left: QIcon
    arrow_elbow_right: QIcon
    arrow_fork: QIcon
    arrow_forward: QIcon
    arrow_forward_up: QIcon
    arrow_forward_up_double: QIcon
    arrow_guide: QIcon
    arrow_iteration: QIcon
    arrow_left: QIcon
    arrow_left_bar: QIcon
    arrow_left_circle: QIcon
    arrow_left_rhombus: QIcon
    arrow_left_right: QIcon
    arrow_left_square: QIcon
    arrow_left_tail: QIcon
    arrow_loop_left: QIcon
    arrow_loop_left_2: QIcon
    arrow_loop_right: QIcon
    arrow_loop_right_2: QIcon
    arrow_merge: QIcon
    arrow_merge_both: QIcon
    arrow_merge_left: QIcon
    arrow_merge_right: QIcon
    arrow_move_down: QIcon
    arrow_move_left: QIcon
    arrow_move_right: QIcon
    arrow_move_up: QIcon
    arrow_narrow_down: QIcon
    arrow_narrow_left: QIcon
    arrow_narrow_right: QIcon
    arrow_narrow_up: QIcon
    arrow_ramp_left: QIcon
    arrow_ramp_left_2: QIcon
    arrow_ramp_left_3: QIcon
    arrow_ramp_right: QIcon
    arrow_ramp_right_2: QIcon
    arrow_ramp_right_3: QIcon
    arrow_right: QIcon
    arrow_right_bar: QIcon
    arrow_right_circle: QIcon
    arrow_right_rhombus: QIcon
    arrow_right_square: QIcon
    arrow_right_tail: QIcon
    arrow_rotary_first_left: QIcon
    arrow_rotary_first_right: QIcon
    arrow_rotary_last_left: QIcon
    arrow_rotary_last_right: QIcon
    arrow_rotary_left: QIcon
    arrow_rotary_right: QIcon
    arrow_rotary_straight: QIcon
    arrow_roundabout_left: QIcon
    arrow_roundabout_right: QIcon
    arrows_cross: QIcon
    arrows_diagonal: QIcon
    arrows_diagonal_2: QIcon
    arrows_diagonal_minimize: QIcon
    arrows_diagonal_minimize_2: QIcon
    arrows_diff: QIcon
    arrows_double_ne_sw: QIcon
    arrows_double_nw_se: QIcon
    arrows_double_se_nw: QIcon
    arrows_double_sw_ne: QIcon
    arrows_down: QIcon
    arrows_down_up: QIcon
    arrows_exchange: QIcon
    arrows_exchange_2: QIcon
    arrow_sharp_turn_left: QIcon
    arrow_sharp_turn_right: QIcon
    arrows_horizontal: QIcon
    arrows_join: QIcon
    arrows_join_2: QIcon
    arrows_left: QIcon
    arrows_left_down: QIcon
    arrows_left_right: QIcon
    arrows_maximize: QIcon
    arrows_minimize: QIcon
    arrows_move: QIcon
    arrows_move_horizontal: QIcon
    arrows_move_vertical: QIcon
    arrows_random: QIcon
    arrows_right: QIcon
    arrows_right_down: QIcon
    arrows_right_left: QIcon
    arrows_shuffle: QIcon
    arrows_shuffle_2: QIcon
    arrows_sort: QIcon
    arrows_split: QIcon
    arrows_split_2: QIcon
    arrows_transfer_down: QIcon
    arrows_transfer_up: QIcon
    arrows_up: QIcon
    arrows_up_down: QIcon
    arrows_up_left: QIcon
    arrows_up_right: QIcon
    arrows_vertical: QIcon
    arrow_up: QIcon
    arrow_up_bar: QIcon
    arrow_up_circle: QIcon
    arrow_up_left: QIcon
    arrow_up_left_circle: QIcon
    arrow_up_rhombus: QIcon
    arrow_up_right: QIcon
    arrow_up_right_circle: QIcon
    arrow_up_square: QIcon
    arrow_up_tail: QIcon
    arrow_wave_left_down: QIcon
    arrow_wave_left_up: QIcon
    arrow_wave_right_down: QIcon
    arrow_wave_right_up: QIcon
    arrow_zig_zag: QIcon
    artboard: QIcon
    artboard_filled: QIcon
    artboard_off: QIcon
    article: QIcon
    article_filled_filled: QIcon
    article_off: QIcon
    aspect_ratio: QIcon
    aspect_ratio_filled: QIcon
    aspect_ratio_off: QIcon
    assembly: QIcon
    assembly_off: QIcon
    asset: QIcon
    asterisk: QIcon
    asterisk_simple: QIcon
    at: QIcon
    at_off: QIcon
    atom: QIcon
    atom_2: QIcon
    atom_2_filled: QIcon
    atom_off: QIcon
    augmented_reality: QIcon
    augmented_reality_2: QIcon
    augmented_reality_off: QIcon
    automatic_gearbox: QIcon
    award: QIcon
    award_filled: QIcon
    award_off: QIcon
    axe: QIcon
    axis_x: QIcon
    axis_y: QIcon
    baby_bottle: QIcon
    baby_carriage: QIcon
    backhoe: QIcon
    backpack: QIcon
    backpack_off: QIcon
    backslash: QIcon
    backspace: QIcon
    backspace_filled: QIcon
    badge: QIcon
    badge_3d: QIcon
    badge_4k: QIcon
    badge_8k: QIcon
    badge_ad: QIcon
    badge_ar: QIcon
    badge_cc: QIcon
    badge_filled: QIcon
    badge_hd: QIcon
    badge_off: QIcon
    badges: QIcon
    badge_sd: QIcon
    badges_filled: QIcon
    badges_off: QIcon
    badge_tm: QIcon
    badge_vo: QIcon
    badge_vr: QIcon
    badge_wc: QIcon
    baguette: QIcon
    ball_american_football: QIcon
    ball_american_football_off: QIcon
    ball_baseball: QIcon
    ball_basketball: QIcon
    ball_bowling: QIcon
    ball_football: QIcon
    ball_football_off: QIcon
    balloon: QIcon
    balloon_filled: QIcon
    balloon_off: QIcon
    ballpen: QIcon
    ballpen_filled: QIcon
    ballpen_off: QIcon
    ball_tennis: QIcon
    ball_volleyball: QIcon
    ban: QIcon
    bandage: QIcon
    bandage_filled: QIcon
    bandage_off: QIcon
    barbell: QIcon
    barbell_off: QIcon
    barcode: QIcon
    barcode_off: QIcon
    barrel: QIcon
    barrel_off: QIcon
    barrier_block: QIcon
    barrier_block_off: QIcon
    baseline: QIcon
    baseline_density_large: QIcon
    baseline_density_medium: QIcon
    baseline_density_small: QIcon
    basket: QIcon
    basket_bolt: QIcon
    basket_cancel: QIcon
    basket_check: QIcon
    basket_code: QIcon
    basket_cog: QIcon
    basket_discount: QIcon
    basket_dollar: QIcon
    basket_down: QIcon
    basket_exclamation: QIcon
    basket_filled: QIcon
    basket_heart: QIcon
    basket_minus: QIcon
    basket_off: QIcon
    basket_pause: QIcon
    basket_pin: QIcon
    basket_plus: QIcon
    basket_question: QIcon
    basket_search: QIcon
    basket_share: QIcon
    basket_star: QIcon
    basket_up: QIcon
    basket_x: QIcon
    bat: QIcon
    bath: QIcon
    bath_filled: QIcon
    bath_off: QIcon
    battery: QIcon
    battery_1: QIcon
    battery_1_filled: QIcon
    battery_2: QIcon
    battery_2_filled: QIcon
    battery_3: QIcon
    battery_3_filled: QIcon
    battery_4: QIcon
    battery_4_filled: QIcon
    battery_automotive: QIcon
    battery_charging: QIcon
    battery_charging_2: QIcon
    battery_eco: QIcon
    battery_filled: QIcon
    battery_off: QIcon
    beach: QIcon
    beach_off: QIcon
    bed: QIcon
    bed_filled: QIcon
    bed_off: QIcon
    beer: QIcon
    beer_filled: QIcon
    beer_off: QIcon
    bell: QIcon
    bell_bolt: QIcon
    bell_cancel: QIcon
    bell_check: QIcon
    bell_code: QIcon
    bell_cog: QIcon
    bell_dollar: QIcon
    bell_down: QIcon
    bell_exclamation: QIcon
    bell_filled: QIcon
    bell_heart: QIcon
    bell_minus: QIcon
    bell_minus_filled: QIcon
    bell_off: QIcon
    bell_pause: QIcon
    bell_pin: QIcon
    bell_plus: QIcon
    bell_plus_filled: QIcon
    bell_question: QIcon
    bell_ringing: QIcon
    bell_ringing_2: QIcon
    bell_ringing_2_filled: QIcon
    bell_ringing_filled: QIcon
    bell_school: QIcon
    bell_search: QIcon
    bell_share: QIcon
    bell_star: QIcon
    bell_up: QIcon
    bell_x: QIcon
    bell_x_filled: QIcon
    bell_z: QIcon
    bell_z_filled: QIcon
    beta: QIcon
    bible: QIcon
    bike: QIcon
    bike_off: QIcon
    binary: QIcon
    binary_off: QIcon
    binary_tree: QIcon
    binary_tree_2: QIcon
    biohazard: QIcon
    biohazard_off: QIcon
    blade: QIcon
    blade_filled: QIcon
    bleach: QIcon
    bleach_chlorine: QIcon
    bleach_no_chlorine: QIcon
    bleach_off: QIcon
    blockquote: QIcon
    bluetooth: QIcon
    bluetooth_connected: QIcon
    bluetooth_off: QIcon
    bluetooth_x: QIcon
    blur: QIcon
    blur_off: QIcon
    bmp: QIcon
    bold: QIcon
    bold_off: QIcon
    bolt: QIcon
    bolt_off: QIcon
    bomb: QIcon
    bomb_filled: QIcon
    bone: QIcon
    bone_off: QIcon
    bong: QIcon
    bong_off: QIcon
    book: QIcon
    book_2: QIcon
    book_download: QIcon
    book_filled: QIcon
    bookmark: QIcon
    bookmark_ai: QIcon
    bookmark_edit: QIcon
    bookmark_filled: QIcon
    bookmark_minus: QIcon
    bookmark_off: QIcon
    bookmark_plus: QIcon
    bookmark_question: QIcon
    bookmarks: QIcon
    bookmarks_filled: QIcon
    bookmarks_off: QIcon
    book_off: QIcon
    books: QIcon
    books_off: QIcon
    book_upload: QIcon
    border_all: QIcon
    border_bottom: QIcon
    border_corners: QIcon
    border_horizontal: QIcon
    border_inner: QIcon
    border_left: QIcon
    border_none: QIcon
    border_outer: QIcon
    border_radius: QIcon
    border_right: QIcon
    border_sides: QIcon
    border_style: QIcon
    border_style_2: QIcon
    border_top: QIcon
    border_vertical: QIcon
    bottle: QIcon
    bottle_filled: QIcon
    bottle_off: QIcon
    bounce_left: QIcon
    bounce_left_filled: QIcon
    bounce_right: QIcon
    bounce_right_filled: QIcon
    bow: QIcon
    bowl: QIcon
    bowl_filled: QIcon
    box: QIcon
    box_align_bottom: QIcon
    box_align_bottom_filled: QIcon
    box_align_bottom_left: QIcon
    box_align_bottom_left_filled: QIcon
    box_align_bottom_right: QIcon
    box_align_bottom_right_filled: QIcon
    box_align_left: QIcon
    box_align_left_filled: QIcon
    box_align_right: QIcon
    box_align_right_filled: QIcon
    box_align_top: QIcon
    box_align_top_filled: QIcon
    box_align_top_left: QIcon
    box_align_top_left_filled: QIcon
    box_align_top_right: QIcon
    box_align_top_right_filled: QIcon
    box_margin: QIcon
    box_model: QIcon
    box_model_2: QIcon
    box_model_2_off: QIcon
    box_model_off: QIcon
    box_multiple: QIcon
    box_multiple_0: QIcon
    box_multiple_1: QIcon
    box_multiple_2: QIcon
    box_multiple_3: QIcon
    box_multiple_4: QIcon
    box_multiple_5: QIcon
    box_multiple_6: QIcon
    box_multiple_7: QIcon
    box_multiple_8: QIcon
    box_multiple_9: QIcon
    box_off: QIcon
    box_padding: QIcon
    box_seam: QIcon
    braces: QIcon
    braces_off: QIcon
    brackets: QIcon
    brackets_contain: QIcon
    brackets_contain_end: QIcon
    brackets_contain_start: QIcon
    brackets_off: QIcon
    braille: QIcon
    brain: QIcon
    brand_4chan: QIcon
    brand_abstract: QIcon
    brand_adobe: QIcon
    brand_adonis_js: QIcon
    brand_airbnb: QIcon
    brand_airtable: QIcon
    brand_algolia: QIcon
    brand_alipay: QIcon
    brand_alpine_js: QIcon
    brand_amazon: QIcon
    brand_amd: QIcon
    brand_amigo: QIcon
    brand_among_us: QIcon
    brand_android: QIcon
    brand_angular: QIcon
    brand_ansible: QIcon
    brand_ao3: QIcon
    brand_appgallery: QIcon
    brand_apple: QIcon
    brand_apple_arcade: QIcon
    brand_apple_podcast: QIcon
    brand_appstore: QIcon
    brand_asana: QIcon
    brand_aws: QIcon
    brand_azure: QIcon
    brand_backbone: QIcon
    brand_badoo: QIcon
    brand_baidu: QIcon
    brand_bandcamp: QIcon
    brand_bandlab: QIcon
    brand_beats: QIcon
    brand_behance: QIcon
    brand_bilibili: QIcon
    brand_binance: QIcon
    brand_bing: QIcon
    brand_bitbucket: QIcon
    brand_blackberry: QIcon
    brand_blender: QIcon
    brand_blogger: QIcon
    brand_booking: QIcon
    brand_bootstrap: QIcon
    brand_bulma: QIcon
    brand_bumble: QIcon
    brand_bunpo: QIcon
    brand_cake: QIcon
    brand_cakephp: QIcon
    brand_campaignmonitor: QIcon
    brand_carbon: QIcon
    brand_cashapp: QIcon
    brand_chrome: QIcon
    brand_cinema_4d: QIcon
    brand_citymapper: QIcon
    brand_cloudflare: QIcon
    brand_codecov: QIcon
    brand_codepen: QIcon
    brand_codesandbox: QIcon
    brand_cohost: QIcon
    brand_coinbase: QIcon
    brand_comedy_central: QIcon
    brand_coreos: QIcon
    brand_couchdb: QIcon
    brand_couchsurfing: QIcon
    brand_cpp: QIcon
    brand_craft: QIcon
    brand_crunchbase: QIcon
    brand_c_sharp: QIcon
    brand_css3: QIcon
    brand_ctemplar: QIcon
    brand_cucumber: QIcon
    brand_cupra: QIcon
    brand_cypress: QIcon
    brand_d3: QIcon
    brand_databricks: QIcon
    brand_days_counter: QIcon
    brand_dcos: QIcon
    brand_debian: QIcon
    brand_deezer: QIcon
    brand_deliveroo: QIcon
    brand_deno: QIcon
    brand_denodo: QIcon
    brand_deviantart: QIcon
    brand_digg: QIcon
    brand_dingtalk: QIcon
    brand_discord: QIcon
    brand_discord_filled: QIcon
    brand_disney: QIcon
    brand_disqus: QIcon
    brand_django: QIcon
    brand_docker: QIcon
    brand_doctrine: QIcon
    brand_dolby_digital: QIcon
    brand_douban: QIcon
    brand_dribbble: QIcon
    brand_dribbble_filled: QIcon
    brand_drops: QIcon
    brand_drupal: QIcon
    brand_edge: QIcon
    brand_elastic: QIcon
    brand_electronic_arts: QIcon
    brand_ember: QIcon
    brand_envato: QIcon
    brand_etsy: QIcon
    brand_evernote: QIcon
    brand_facebook: QIcon
    brand_facebook_filled: QIcon
    brand_feedly: QIcon
    brand_figma: QIcon
    brand_filezilla: QIcon
    brand_finder: QIcon
    brand_firebase: QIcon
    brand_firefox: QIcon
    brand_fiverr: QIcon
    brand_flickr: QIcon
    brand_flightradar24: QIcon
    brand_flipboard: QIcon
    brand_flutter: QIcon
    brand_fortnite: QIcon
    brand_foursquare: QIcon
    brand_framer: QIcon
    brand_framer_motion: QIcon
    brand_funimation: QIcon
    brand_gatsby: QIcon
    brand_git: QIcon
    brand_github: QIcon
    brand_github_copilot: QIcon
    brand_github_filled: QIcon
    brand_gitlab: QIcon
    brand_gmail: QIcon
    brand_golang: QIcon
    brand_google: QIcon
    brand_google_analytics: QIcon
    brand_google_big_query: QIcon
    brand_google_drive: QIcon
    brand_google_fit: QIcon
    brand_google_home: QIcon
    brand_google_maps: QIcon
    brand_google_one: QIcon
    brand_google_photos: QIcon
    brand_google_play: QIcon
    brand_google_podcasts: QIcon
    brand_grammarly: QIcon
    brand_graphql: QIcon
    brand_gravatar: QIcon
    brand_grindr: QIcon
    brand_guardian: QIcon
    brand_gumroad: QIcon
    brand_hbo: QIcon
    brand_headlessui: QIcon
    brand_hexo: QIcon
    brand_hipchat: QIcon
    brand_html5: QIcon
    brand_inertia: QIcon
    brand_instagram: QIcon
    brand_intercom: QIcon
    brand_itch: QIcon
    brand_javascript: QIcon
    brand_juejin: QIcon
    brand_kbin: QIcon
    brand_kick: QIcon
    brand_kickstarter: QIcon
    brand_kotlin: QIcon
    brand_laravel: QIcon
    brand_lastfm: QIcon
    brand_leetcode: QIcon
    brand_letterboxd: QIcon
    brand_line: QIcon
    brand_linkedin: QIcon
    brand_linktree: QIcon
    brand_linqpad: QIcon
    brand_loom: QIcon
    brand_mailgun: QIcon
    brand_mantine: QIcon
    brand_mastercard: QIcon
    brand_mastodon: QIcon
    brand_matrix: QIcon
    brand_mcdonalds: QIcon
    brand_medium: QIcon
    brand_meetup: QIcon
    brand_mercedes: QIcon
    brand_messenger: QIcon
    brand_meta: QIcon
    brand_microsoft_teams: QIcon
    brand_minecraft: QIcon
    brand_miniprogram: QIcon
    brand_mixpanel: QIcon
    brand_monday: QIcon
    brand_mongodb: QIcon
    brand_my_oppo: QIcon
    brand_mysql: QIcon
    brand_national_geographic: QIcon
    brand_nem: QIcon
    brand_netbeans: QIcon
    brand_netease_music: QIcon
    brand_netflix: QIcon
    brand_nexo: QIcon
    brand_nextcloud: QIcon
    brand_nextjs: QIcon
    brand_nodejs: QIcon
    brand_nord_vpn: QIcon
    brand_notion: QIcon
    brand_npm: QIcon
    brand_nuxt: QIcon
    brand_nytimes: QIcon
    brand_oauth: QIcon
    brand_office: QIcon
    brand_ok_ru: QIcon
    brand_onedrive: QIcon
    brand_onlyfans: QIcon
    brand_openai: QIcon
    brand_open_source: QIcon
    brand_openvpn: QIcon
    brand_opera: QIcon
    brand_pagekit: QIcon
    brand_parsinta: QIcon
    brand_patreon: QIcon
    brand_paypal: QIcon
    brand_paypal_filled: QIcon
    brand_paypay: QIcon
    brand_peanut: QIcon
    brand_pepsi: QIcon
    brand_php: QIcon
    brand_picsart: QIcon
    brand_pinterest: QIcon
    brand_planetscale: QIcon
    brand_pocket: QIcon
    brand_polymer: QIcon
    brand_powershell: QIcon
    brand_prisma: QIcon
    brand_producthunt: QIcon
    brand_pushbullet: QIcon
    brand_pushover: QIcon
    brand_python: QIcon
    brand_qq: QIcon
    brand_radix_ui: QIcon
    brand_react: QIcon
    brand_react_native: QIcon
    brand_reason: QIcon
    brand_reddit: QIcon
    brand_redhat: QIcon
    brand_redux: QIcon
    brand_revolut: QIcon
    brand_rumble: QIcon
    brand_rust: QIcon
    brand_safari: QIcon
    brand_samsungpass: QIcon
    brand_sass: QIcon
    brand_sentry: QIcon
    brand_sharik: QIcon
    brand_shazam: QIcon
    brand_shopee: QIcon
    brand_sketch: QIcon
    brand_skype: QIcon
    brand_slack: QIcon
    brand_snapchat: QIcon
    brand_snapseed: QIcon
    brand_snowflake: QIcon
    brand_socket_io: QIcon
    brand_solidjs: QIcon
    brand_soundcloud: QIcon
    brand_spacehey: QIcon
    brand_speedtest: QIcon
    brand_spotify: QIcon
    brand_stackoverflow: QIcon
    brand_stackshare: QIcon
    brand_steam: QIcon
    brand_storj: QIcon
    brand_storybook: QIcon
    brand_storytel: QIcon
    brand_strava: QIcon
    brand_stripe: QIcon
    brand_sublime_text: QIcon
    brand_sugarizer: QIcon
    brand_supabase: QIcon
    brand_superhuman: QIcon
    brand_supernova: QIcon
    brand_surfshark: QIcon
    brand_svelte: QIcon
    brand_swift: QIcon
    brand_symfony: QIcon
    brand_tabler: QIcon
    brand_tailwind: QIcon
    brand_taobao: QIcon
    brand_teams: QIcon
    brand_ted: QIcon
    brand_telegram: QIcon
    brand_terraform: QIcon
    brand_tether: QIcon
    brand_threads: QIcon
    brand_threejs: QIcon
    brand_tidal: QIcon
    brand_tikto_filled: QIcon
    brand_tiktok: QIcon
    brand_tiktok_filled: QIcon
    brand_tinder: QIcon
    brand_topbuzz: QIcon
    brand_torchain: QIcon
    brand_toyota: QIcon
    brand_trello: QIcon
    brand_tripadvisor: QIcon
    brand_tumblr: QIcon
    brand_twilio: QIcon
    brand_twitch: QIcon
    brand_twitter: QIcon
    brand_twitter_filled: QIcon
    brand_typescript: QIcon
    brand_uber: QIcon
    brand_ubuntu: QIcon
    brand_unity: QIcon
    brand_unsplash: QIcon
    brand_upwork: QIcon
    brand_valorant: QIcon
    brand_vercel: QIcon
    brand_vimeo: QIcon
    brand_vinted: QIcon
    brand_visa: QIcon
    brand_visual_studio: QIcon
    brand_vite: QIcon
    brand_vivaldi: QIcon
    brand_vk: QIcon
    brand_vlc: QIcon
    brand_volkswagen: QIcon
    brand_vsco: QIcon
    brand_vscode: QIcon
    brand_vue: QIcon
    brand_walmart: QIcon
    brand_waze: QIcon
    brand_webflow: QIcon
    brand_wechat: QIcon
    brand_weibo: QIcon
    brand_whatsapp: QIcon
    brand_wikipedia: QIcon
    brand_windows: QIcon
    brand_windy: QIcon
    brand_wish: QIcon
    brand_wix: QIcon
    brand_wordpress: QIcon
    brand_x: QIcon
    brand_xamarin: QIcon
    brand_xbox: QIcon
    brand_xdeep: QIcon
    brand_x_filled: QIcon
    brand_xing: QIcon
    brand_yahoo: QIcon
    brand_yandex: QIcon
    brand_yatse: QIcon
    brand_ycombinator: QIcon
    brand_youtube: QIcon
    brand_youtube_filled: QIcon
    brand_youtube_kids: QIcon
    brand_zalando: QIcon
    brand_zapier: QIcon
    brand_zeit: QIcon
    brand_zhihu: QIcon
    brand_zoom: QIcon
    brand_zulip: QIcon
    brand_zwift: QIcon
    bread: QIcon
    bread_off: QIcon
    briefcase: QIcon
    briefcase_2: QIcon
    briefcase_off: QIcon
    brightness: QIcon
    brightness_2: QIcon
    brightness_down: QIcon
    brightness_down_filled: QIcon
    brightness_half: QIcon
    brightness_off: QIcon
    brightness_up: QIcon
    brightness_up_filled: QIcon
    broadcast: QIcon
    broadcast_off: QIcon
    browser: QIcon
    browser_check: QIcon
    browser_off: QIcon
    browser_plus: QIcon
    browser_x: QIcon
    brush: QIcon
    brush_off: QIcon
    bucket: QIcon
    bucket_droplet: QIcon
    bucket_off: QIcon
    bug: QIcon
    bug_off: QIcon
    building: QIcon
    building_arch: QIcon
    building_bank: QIcon
    building_bridge: QIcon
    building_bridge_2: QIcon
    building_broadcast_tower: QIcon
    building_carousel: QIcon
    building_castle: QIcon
    building_church: QIcon
    building_circus: QIcon
    building_community: QIcon
    building_cottage: QIcon
    building_estate: QIcon
    building_factory: QIcon
    building_factory_2: QIcon
    building_fortress: QIcon
    building_hospital: QIcon
    building_lighthouse: QIcon
    building_monument: QIcon
    building_mosque: QIcon
    building_pavilion: QIcon
    building_skyscraper: QIcon
    building_stadium: QIcon
    building_store: QIcon
    building_tunnel: QIcon
    building_warehouse: QIcon
    building_wind_turbine: QIcon
    bulb: QIcon
    bulb_filled: QIcon
    bulb_off: QIcon
    bulldozer: QIcon
    bus: QIcon
    businessplan: QIcon
    bus_off: QIcon
    bus_stop: QIcon
    butterfly: QIcon
    cactus: QIcon
    cactus_filled: QIcon
    cactus_off: QIcon
    cake: QIcon
    cake_off: QIcon
    calculator: QIcon
    calculator_filled: QIcon
    calculator_off: QIcon
    calendar: QIcon
    calendar_bolt: QIcon
    calendar_cancel: QIcon
    calendar_check: QIcon
    calendar_code: QIcon
    calendar_cog: QIcon
    calendar_dollar: QIcon
    calendar_down: QIcon
    calendar_due: QIcon
    calendar_event: QIcon
    calendar_exclamation: QIcon
    calendar_filled: QIcon
    calendar_heart: QIcon
    calendar_minus: QIcon
    calendar_off: QIcon
    calendar_pause: QIcon
    calendar_pin: QIcon
    calendar_plus: QIcon
    calendar_question: QIcon
    calendar_repeat: QIcon
    calendar_search: QIcon
    calendar_share: QIcon
    calendar_star: QIcon
    calendar_stats: QIcon
    calendar_time: QIcon
    calendar_up: QIcon
    calendar_x: QIcon
    camera: QIcon
    camera_bolt: QIcon
    camera_cancel: QIcon
    camera_check: QIcon
    camera_code: QIcon
    camera_cog: QIcon
    camera_dollar: QIcon
    camera_down: QIcon
    camera_exclamation: QIcon
    camera_filled: QIcon
    camera_heart: QIcon
    camera_minus: QIcon
    camera_off: QIcon
    camera_pause: QIcon
    camera_pin: QIcon
    camera_plus: QIcon
    camera_question: QIcon
    camera_rotate: QIcon
    camera_search: QIcon
    camera_selfie: QIcon
    camera_share: QIcon
    camera_star: QIcon
    camera_up: QIcon
    camera_x: QIcon
    camper: QIcon
    campfire: QIcon
    campfire_filled: QIcon
    candle: QIcon
    candle_filled: QIcon
    candy: QIcon
    candy_off: QIcon
    cane: QIcon
    cannabis: QIcon
    capsule: QIcon
    capsule_filled: QIcon
    capsule_horizontal: QIcon
    capsule_horizontal_filled: QIcon
    capture: QIcon
    capture_filled: QIcon
    capture_off: QIcon
    car: QIcon
    caravan: QIcon
    car_crane: QIcon
    car_crash: QIcon
    cardboards: QIcon
    cardboards_off: QIcon
    cards: QIcon
    cards_filled: QIcon
    caret_down: QIcon
    caret_down_filled: QIcon
    caret_left: QIcon
    caret_left_filled: QIcon
    caret_left_right: QIcon
    caret_right: QIcon
    caret_right_filled: QIcon
    caret_up: QIcon
    caret_up_down: QIcon
    caret_up_filled: QIcon
    car_garage: QIcon
    car_off: QIcon
    carousel_horizontal: QIcon
    carousel_horizontal_filled: QIcon
    carousel_vertical: QIcon
    carousel_vertical_filled: QIcon
    carrot: QIcon
    carrot_off: QIcon
    car_suv: QIcon
    cart_bolt: QIcon
    cart_cancel: QIcon
    cart_check: QIcon
    cart_code: QIcon
    cart_cog: QIcon
    cart_copy: QIcon
    cart_discount: QIcon
    cart_dollar: QIcon
    cart_down: QIcon
    cart_exclamation: QIcon
    cart_heart: QIcon
    cart_minus: QIcon
    cart_pause: QIcon
    cart_pin: QIcon
    cart_plus: QIcon
    cart_question: QIcon
    cart_search: QIcon
    cart_share: QIcon
    cart_star: QIcon
    cart_up: QIcon
    car_turbine: QIcon
    cart_x: QIcon
    cash: QIcon
    cash_banknote: QIcon
    cash_banknote_off: QIcon
    cash_off: QIcon
    cast: QIcon
    cast_off: QIcon
    cat: QIcon
    category: QIcon
    category_2: QIcon
    category_filled: QIcon
    ce: QIcon
    cell: QIcon
    cell_signal_1: QIcon
    cell_signal_2: QIcon
    cell_signal_3: QIcon
    cell_signal_4: QIcon
    cell_signal_5: QIcon
    cell_signal_off: QIcon
    ce_off: QIcon
    certificate: QIcon
    certificate_2: QIcon
    certificate_2_off: QIcon
    certificate_off: QIcon
    chair_director: QIcon
    chalkboard: QIcon
    chalkboard_off: QIcon
    charging_pile: QIcon
    chart_arcs: QIcon
    chart_arcs_3: QIcon
    chart_area: QIcon
    chart_area_filled: QIcon
    chart_area_line: QIcon
    chart_area_line_filled: QIcon
    chart_arrows: QIcon
    chart_arrows_vertical: QIcon
    chart_bar: QIcon
    chart_bar_off: QIcon
    chart_bubble: QIcon
    chart_bubble_filled: QIcon
    chart_candle: QIcon
    chart_candle_filled: QIcon
    chart_circles: QIcon
    chart_donut: QIcon
    chart_donut_2: QIcon
    chart_donut_3: QIcon
    chart_donut_4: QIcon
    chart_donut_filled: QIcon
    chart_dots: QIcon
    chart_dots_2: QIcon
    chart_dots_3: QIcon
    chart_grid_dots: QIcon
    chart_histogram: QIcon
    chart_infographic: QIcon
    chart_line: QIcon
    chart_pie: QIcon
    chart_pie_2: QIcon
    chart_pie_3: QIcon
    chart_pie_4: QIcon
    chart_pie_filled: QIcon
    chart_pie_off: QIcon
    chart_ppf: QIcon
    chart_radar: QIcon
    chart_sankey: QIcon
    chart_treemap: QIcon
    check: QIcon
    checkbox: QIcon
    checklist: QIcon
    checks: QIcon
    checkup_list: QIcon
    cheese: QIcon
    chef_hat: QIcon
    chef_hat_off: QIcon
    cherry: QIcon
    cherry_filled: QIcon
    chess: QIcon
    chess_bishop: QIcon
    chess_bishop_filled: QIcon
    chess_filled: QIcon
    chess_king: QIcon
    chess_king_filled: QIcon
    chess_knight: QIcon
    chess_knight_filled: QIcon
    chess_queen: QIcon
    chess_queen_filled: QIcon
    chess_rook: QIcon
    chess_rook_filled: QIcon
    chevron_compact_down: QIcon
    chevron_compact_left: QIcon
    chevron_compact_right: QIcon
    chevron_compact_up: QIcon
    chevron_down: QIcon
    chevron_down_left: QIcon
    chevron_down_right: QIcon
    chevron_left: QIcon
    chevron_left_pipe: QIcon
    chevron_right: QIcon
    chevron_right_pipe: QIcon
    chevrons_down: QIcon
    chevrons_down_left: QIcon
    chevrons_down_right: QIcon
    chevrons_left: QIcon
    chevrons_right: QIcon
    chevrons_up: QIcon
    chevrons_up_left: QIcon
    chevrons_up_right: QIcon
    chevron_up: QIcon
    chevron_up_left: QIcon
    chevron_up_right: QIcon
    chisel: QIcon
    christmas_tree: QIcon
    christmas_tree_off: QIcon
    circle: QIcon
    circle_0_filled: QIcon
    circle_1_filled: QIcon
    circle_2_filled: QIcon
    circle_3_filled: QIcon
    circle_4_filled: QIcon
    circle_5_filled: QIcon
    circle_6_filled: QIcon
    circle_7_filled: QIcon
    circle_8_filled: QIcon
    circle_9_filled: QIcon
    circle_arrow_down: QIcon
    circle_arrow_down_filled: QIcon
    circle_arrow_down_left: QIcon
    circle_arrow_down_left_filled: QIcon
    circle_arrow_down_right: QIcon
    circle_arrow_down_right_filled: QIcon
    circle_arrow_left: QIcon
    circle_arrow_left_filled: QIcon
    circle_arrow_right: QIcon
    circle_arrow_right_filled: QIcon
    circle_arrow_up: QIcon
    circle_arrow_up_filled: QIcon
    circle_arrow_up_left: QIcon
    circle_arrow_up_left_filled: QIcon
    circle_arrow_up_right: QIcon
    circle_arrow_up_right_filled: QIcon
    circle_caret_down: QIcon
    circle_caret_left: QIcon
    circle_caret_right: QIcon
    circle_caret_up: QIcon
    circle_check: QIcon
    circle_check_filled: QIcon
    circle_chevron_down: QIcon
    circle_chevron_left: QIcon
    circle_chevron_right: QIcon
    circle_chevrons_down: QIcon
    circle_chevrons_left: QIcon
    circle_chevrons_right: QIcon
    circle_chevrons_up: QIcon
    circle_chevron_up: QIcon
    circle_dashed: QIcon
    circle_dashed_number_0: QIcon
    circle_dashed_number_1: QIcon
    circle_dashed_number_2: QIcon
    circle_dashed_number_3: QIcon
    circle_dashed_number_4: QIcon
    circle_dashed_number_5: QIcon
    circle_dashed_number_6: QIcon
    circle_dashed_number_7: QIcon
    circle_dashed_number_8: QIcon
    circle_dashed_number_9: QIcon
    circle_dashed_x: QIcon
    circle_dot: QIcon
    circle_dot_filled: QIcon
    circle_dotted: QIcon
    circle_filled: QIcon
    circle_half: QIcon
    circle_half_2: QIcon
    circle_half_vertical: QIcon
    circle_key: QIcon
    circle_key_filled: QIcon
    circle_letter_a: QIcon
    circle_letter_b: QIcon
    circle_letter_c: QIcon
    circle_letter_d: QIcon
    circle_letter_e: QIcon
    circle_letter_f: QIcon
    circle_letter_g: QIcon
    circle_letter_h: QIcon
    circle_letter_i: QIcon
    circle_letter_j: QIcon
    circle_letter_k: QIcon
    circle_letter_l: QIcon
    circle_letter_m: QIcon
    circle_letter_n: QIcon
    circle_letter_o: QIcon
    circle_letter_p: QIcon
    circle_letter_q: QIcon
    circle_letter_r: QIcon
    circle_letter_s: QIcon
    circle_letter_t: QIcon
    circle_letter_u: QIcon
    circle_letter_v: QIcon
    circle_letter_w: QIcon
    circle_letter_x: QIcon
    circle_letter_y: QIcon
    circle_letter_z: QIcon
    circle_minus: QIcon
    circle_minus_2: QIcon
    circle_number_0: QIcon
    circle_number_1: QIcon
    circle_number_2: QIcon
    circle_number_3: QIcon
    circle_number_4: QIcon
    circle_number_5: QIcon
    circle_number_6: QIcon
    circle_number_7: QIcon
    circle_number_8: QIcon
    circle_number_9: QIcon
    circle_off: QIcon
    circle_plus: QIcon
    circle_plus_2: QIcon
    circle_rectangle: QIcon
    circle_rectangle_off: QIcon
    circles: QIcon
    circles_filled: QIcon
    circle_square: QIcon
    circles_relation: QIcon
    circle_triangle: QIcon
    circle_x: QIcon
    circle_x_filled: QIcon
    circuit_ammeter: QIcon
    circuit_battery: QIcon
    circuit_bulb: QIcon
    circuit_capacitor: QIcon
    circuit_capacitor_polarized: QIcon
    circuit_cell: QIcon
    circuit_cell_plus: QIcon
    circuit_changeover: QIcon
    circuit_diode: QIcon
    circuit_diode_zener: QIcon
    circuit_ground: QIcon
    circuit_ground_digital: QIcon
    circuit_inductor: QIcon
    circuit_motor: QIcon
    circuit_pushbutton: QIcon
    circuit_resistor: QIcon
    circuit_switch_closed: QIcon
    circuit_switch_open: QIcon
    circuit_voltmeter: QIcon
    clear_all: QIcon
    clear_formatting: QIcon
    click: QIcon
    clipboard: QIcon
    clipboard_check: QIcon
    clipboard_copy: QIcon
    clipboard_data: QIcon
    clipboard_heart: QIcon
    clipboard_list: QIcon
    clipboard_off: QIcon
    clipboard_plus: QIcon
    clipboard_text: QIcon
    clipboard_typography: QIcon
    clipboard_x: QIcon
    clock: QIcon
    clock_12: QIcon
    clock_2: QIcon
    clock_24: QIcon
    clock_bolt: QIcon
    clock_cancel: QIcon
    clock_check: QIcon
    clock_code: QIcon
    clock_cog: QIcon
    clock_dollar: QIcon
    clock_down: QIcon
    clock_edit: QIcon
    clock_exclamation: QIcon
    clock_filled: QIcon
    clock_heart: QIcon
    clock_hour_1: QIcon
    clock_hour_10: QIcon
    clock_hour_11: QIcon
    clock_hour_12: QIcon
    clock_hour_2: QIcon
    clock_hour_3: QIcon
    clock_hour_4: QIcon
    clock_hour_5: QIcon
    clock_hour_6: QIcon
    clock_hour_7: QIcon
    clock_hour_8: QIcon
    clock_hour_9: QIcon
    clock_minus: QIcon
    clock_off: QIcon
    clock_pause: QIcon
    clock_pin: QIcon
    clock_play: QIcon
    clock_plus: QIcon
    clock_question: QIcon
    clock_record: QIcon
    clock_search: QIcon
    clock_share: QIcon
    clock_shield: QIcon
    clock_star: QIcon
    clock_stop: QIcon
    clock_up: QIcon
    clock_x: QIcon
    clothes_rack: QIcon
    clothes_rack_off: QIcon
    cloud: QIcon
    cloud_bolt: QIcon
    cloud_cancel: QIcon
    cloud_check: QIcon
    cloud_code: QIcon
    cloud_cog: QIcon
    cloud_computing: QIcon
    cloud_data_connection: QIcon
    cloud_dollar: QIcon
    cloud_down: QIcon
    cloud_download: QIcon
    cloud_exclamation: QIcon
    cloud_filled: QIcon
    cloud_fog: QIcon
    cloud_heart: QIcon
    cloud_lock: QIcon
    cloud_lock_open: QIcon
    cloud_minus: QIcon
    cloud_network: QIcon
    cloud_off: QIcon
    cloud_pause: QIcon
    cloud_pin: QIcon
    cloud_plus: QIcon
    cloud_question: QIcon
    cloud_rain: QIcon
    cloud_search: QIcon
    cloud_share: QIcon
    cloud_snow: QIcon
    cloud_star: QIcon
    cloud_storm: QIcon
    cloud_up: QIcon
    cloud_upload: QIcon
    cloud_x: QIcon
    clover: QIcon
    clover_2: QIcon
    clubs: QIcon
    clubs_filled: QIcon
    code: QIcon
    code_asterix: QIcon
    code_circle: QIcon
    code_circle_2: QIcon
    code_dots: QIcon
    code_minus: QIcon
    code_off: QIcon
    code_plus: QIcon
    coffee: QIcon
    coffee_off: QIcon
    coffin: QIcon
    coin: QIcon
    coin_bitcoin: QIcon
    coin_euro: QIcon
    coin_monero: QIcon
    coin_off: QIcon
    coin_pound: QIcon
    coin_rupee: QIcon
    coins: QIcon
    coin_yen: QIcon
    coin_yuan: QIcon
    color_filter: QIcon
    color_picker: QIcon
    color_picker_off: QIcon
    color_swatch: QIcon
    color_swatch_off: QIcon
    column_insert_left: QIcon
    column_insert_right: QIcon
    column_remove: QIcon
    columns: QIcon
    columns_1: QIcon
    columns_2: QIcon
    columns_3: QIcon
    columns_off: QIcon
    comet: QIcon
    command: QIcon
    command_off: QIcon
    compass: QIcon
    compass_off: QIcon
    components: QIcon
    components_off: QIcon
    cone: QIcon
    cone_2: QIcon
    cone_off: QIcon
    cone_plus: QIcon
    confetti: QIcon
    confetti_off: QIcon
    confucius: QIcon
    container: QIcon
    container_off: QIcon
    contrast: QIcon
    contrast_2: QIcon
    contrast_2_off: QIcon
    contrast_off: QIcon
    cooker: QIcon
    cookie: QIcon
    cookie_man: QIcon
    cookie_off: QIcon
    copy: QIcon
    copyleft: QIcon
    copyleft_filled: QIcon
    copyleft_off: QIcon
    copy_off: QIcon
    copyright: QIcon
    copyright_filled: QIcon
    copyright_off: QIcon
    corner_down_left: QIcon
    corner_down_left_double: QIcon
    corner_down_right: QIcon
    corner_down_right_double: QIcon
    corner_left_down: QIcon
    corner_left_down_double: QIcon
    corner_left_up: QIcon
    corner_left_up_double: QIcon
    corner_right_down: QIcon
    corner_right_down_double: QIcon
    corner_right_up: QIcon
    corner_right_up_double: QIcon
    corner_up_left: QIcon
    corner_up_left_double: QIcon
    corner_up_right: QIcon
    corner_up_right_double: QIcon
    cpu: QIcon
    cpu_2: QIcon
    cpu_off: QIcon
    crane: QIcon
    crane_off: QIcon
    creative_commons: QIcon
    creative_commons_by: QIcon
    creative_commons_nc: QIcon
    creative_commons_nd: QIcon
    creative_commons_off: QIcon
    creative_commons_sa: QIcon
    creative_commons_zero: QIcon
    credit_card: QIcon
    credit_card_off: QIcon
    cricket: QIcon
    crop: QIcon
    cross: QIcon
    cross_filled: QIcon
    crosshair: QIcon
    cross_off: QIcon
    crown: QIcon
    crown_off: QIcon
    crutches: QIcon
    crutches_off: QIcon
    crystal_ball: QIcon
    csv: QIcon
    cube: QIcon
    cube_off: QIcon
    cube_plus: QIcon
    cube_send: QIcon
    cube_unfolded: QIcon
    cup: QIcon
    cup_off: QIcon
    curling: QIcon
    curly_loop: QIcon
    currency: QIcon
    currency_afghani: QIcon
    currency_bahraini: QIcon
    currency_baht: QIcon
    currency_bitcoin: QIcon
    currency_cent: QIcon
    currency_dinar: QIcon
    currency_dirham: QIcon
    currency_dogecoin: QIcon
    currency_dollar: QIcon
    currency_dollar_australian: QIcon
    currency_dollar_brunei: QIcon
    currency_dollar_canadian: QIcon
    currency_dollar_guyanese: QIcon
    currency_dollar_off: QIcon
    currency_dollar_singapore: QIcon
    currency_dollar_zimbabwean: QIcon
    currency_dong: QIcon
    currency_dram: QIcon
    currency_ethereum: QIcon
    currency_euro: QIcon
    currency_euro_off: QIcon
    currency_florin: QIcon
    currency_forint: QIcon
    currency_frank: QIcon
    currency_guarani: QIcon
    currency_hryvnia: QIcon
    currency_iranian_rial: QIcon
    currency_kip: QIcon
    currency_krone_czech: QIcon
    currency_krone_danish: QIcon
    currency_krone_swedish: QIcon
    currency_lari: QIcon
    currency_leu: QIcon
    currency_lira: QIcon
    currency_litecoin: QIcon
    currency_lyd: QIcon
    currency_manat: QIcon
    currency_monero: QIcon
    currency_naira: QIcon
    currency_nano: QIcon
    currency_off: QIcon
    currency_paanga: QIcon
    currency_peso: QIcon
    currency_pound: QIcon
    currency_pound_off: QIcon
    currency_quetzal: QIcon
    currency_real: QIcon
    currency_renminbi: QIcon
    currency_ripple: QIcon
    currency_riyal: QIcon
    currency_rubel: QIcon
    currency_rufiyaa: QIcon
    currency_rupee: QIcon
    currency_rupee_nepalese: QIcon
    currency_shekel: QIcon
    currency_solana: QIcon
    currency_som: QIcon
    currency_taka: QIcon
    currency_tenge: QIcon
    currency_tugrik: QIcon
    currency_won: QIcon
    currency_yen: QIcon
    currency_yen_off: QIcon
    currency_yuan: QIcon
    currency_zloty: QIcon
    current_location: QIcon
    current_location_off: QIcon
    cursor_off: QIcon
    cursor_text: QIcon
    cut: QIcon
    cylinder: QIcon
    cylinder_off: QIcon
    cylinder_plus: QIcon
    dashboard: QIcon
    dashboard_off: QIcon
    database: QIcon
    database_cog: QIcon
    database_dollar: QIcon
    database_edit: QIcon
    database_exclamation: QIcon
    database_export: QIcon
    database_heart: QIcon
    database_import: QIcon
    database_leak: QIcon
    database_minus: QIcon
    database_off: QIcon
    database_plus: QIcon
    database_search: QIcon
    database_share: QIcon
    database_star: QIcon
    database_x: QIcon
    decimal: QIcon
    deer: QIcon
    delta: QIcon
    dental: QIcon
    dental_broken: QIcon
    dental_off: QIcon
    deselect: QIcon
    details: QIcon
    details_off: QIcon
    device_airpods: QIcon
    device_airpods_case: QIcon
    device_airtag: QIcon
    device_analytics: QIcon
    device_audio_tape: QIcon
    device_camera_phone: QIcon
    device_cctv: QIcon
    device_cctv_off: QIcon
    device_computer_camera: QIcon
    device_computer_camera_off: QIcon
    device_desktop: QIcon
    device_desktop_analytics: QIcon
    device_desktop_bolt: QIcon
    device_desktop_cancel: QIcon
    device_desktop_check: QIcon
    device_desktop_code: QIcon
    device_desktop_cog: QIcon
    device_desktop_dollar: QIcon
    device_desktop_down: QIcon
    device_desktop_exclamation: QIcon
    device_desktop_heart: QIcon
    device_desktop_minus: QIcon
    device_desktop_off: QIcon
    device_desktop_pause: QIcon
    device_desktop_pin: QIcon
    device_desktop_plus: QIcon
    device_desktop_question: QIcon
    device_desktop_search: QIcon
    device_desktop_share: QIcon
    device_desktop_star: QIcon
    device_desktop_up: QIcon
    device_desktop_x: QIcon
    device_floppy: QIcon
    device_gamepad: QIcon
    device_game_pad: QIcon
    device_gamepad_2: QIcon
    device_heart_monitor: QIcon
    device_heart_monitor_filled: QIcon
    device_imac: QIcon
    device_imac_bolt: QIcon
    device_imac_cancel: QIcon
    device_imac_check: QIcon
    device_imac_code: QIcon
    device_imac_cog: QIcon
    device_imac_dollar: QIcon
    device_imac_down: QIcon
    device_imac_exclamation: QIcon
    device_imac_heart: QIcon
    device_imac_minus: QIcon
    device_imac_off: QIcon
    device_imac_pause: QIcon
    device_imac_pin: QIcon
    device_imac_plus: QIcon
    device_imac_question: QIcon
    device_imac_search: QIcon
    device_imac_share: QIcon
    device_imac_star: QIcon
    device_imac_up: QIcon
    device_imac_x: QIcon
    device_ipad: QIcon
    device_ipad_bolt: QIcon
    device_ipad_cancel: QIcon
    device_ipad_check: QIcon
    device_ipad_code: QIcon
    device_ipad_cog: QIcon
    device_ipad_dollar: QIcon
    device_ipad_down: QIcon
    device_ipad_exclamation: QIcon
    device_ipad_heart: QIcon
    device_ipad_horizontal: QIcon
    device_ipad_horizontal_bolt: QIcon
    device_ipad_horizontal_cancel: QIcon
    device_ipad_horizontal_check: QIcon
    device_ipad_horizontal_code: QIcon
    device_ipad_horizontal_cog: QIcon
    device_ipad_horizontal_dollar: QIcon
    device_ipad_horizontal_down: QIcon
    device_ipad_horizontal_exclamation: QIcon
    device_ipad_horizontal_heart: QIcon
    device_ipad_horizontal_minus: QIcon
    device_ipad_horizontal_off: QIcon
    device_ipad_horizontal_pause: QIcon
    device_ipad_horizontal_pin: QIcon
    device_ipad_horizontal_plus: QIcon
    device_ipad_horizontal_question: QIcon
    device_ipad_horizontal_search: QIcon
    device_ipad_horizontal_share: QIcon
    device_ipad_horizontal_star: QIcon
    device_ipad_horizontal_up: QIcon
    device_ipad_horizontal_x: QIcon
    device_ipad_minus: QIcon
    device_ipad_off: QIcon
    device_ipad_pause: QIcon
    device_ipad_pin: QIcon
    device_ipad_plus: QIcon
    device_ipad_question: QIcon
    device_ipad_search: QIcon
    device_ipad_share: QIcon
    device_ipad_star: QIcon
    device_ipad_up: QIcon
    device_ipad_x: QIcon
    device_landline_phone: QIcon
    device_laptop: QIcon
    device_laptop_off: QIcon
    device_mobile: QIcon
    device_mobile_bolt: QIcon
    device_mobile_cancel: QIcon
    device_mobile_charging: QIcon
    device_mobile_check: QIcon
    device_mobile_code: QIcon
    device_mobile_cog: QIcon
    device_mobile_dollar: QIcon
    device_mobile_down: QIcon
    device_mobile_exclamation: QIcon
    device_mobile_filled: QIcon
    device_mobile_heart: QIcon
    device_mobile_message: QIcon
    device_mobile_minus: QIcon
    device_mobile_off: QIcon
    device_mobile_pause: QIcon
    device_mobile_pin: QIcon
    device_mobile_plus: QIcon
    device_mobile_question: QIcon
    device_mobile_rotated: QIcon
    device_mobile_search: QIcon
    device_mobile_share: QIcon
    device_mobile_star: QIcon
    device_mobile_up: QIcon
    device_mobile_vibration: QIcon
    device_mobile_x: QIcon
    device_nintendo: QIcon
    device_nintendo_off: QIcon
    device_projector: QIcon
    device_remote: QIcon
    devices: QIcon
    devices_2: QIcon
    devices_bolt: QIcon
    devices_cancel: QIcon
    devices_check: QIcon
    devices_code: QIcon
    devices_cog: QIcon
    device_sd_card: QIcon
    devices_dollar: QIcon
    devices_down: QIcon
    devices_exclamation: QIcon
    devices_heart: QIcon
    device_sim: QIcon
    device_sim_1: QIcon
    device_sim_2: QIcon
    device_sim_3: QIcon
    devices_minus: QIcon
    devices_off: QIcon
    devices_pause: QIcon
    devices_pc: QIcon
    devices_pc_off: QIcon
    device_speaker: QIcon
    device_speaker_off: QIcon
    devices_pin: QIcon
    devices_plus: QIcon
    devices_question: QIcon
    devices_search: QIcon
    devices_share: QIcon
    devices_star: QIcon
    devices_up: QIcon
    devices_x: QIcon
    device_tablet: QIcon
    device_tablet_bolt: QIcon
    device_tablet_cancel: QIcon
    device_tablet_check: QIcon
    device_tablet_code: QIcon
    device_tablet_cog: QIcon
    device_tablet_dollar: QIcon
    device_tablet_down: QIcon
    device_tablet_exclamation: QIcon
    device_tablet_filled: QIcon
    device_tablet_heart: QIcon
    device_tablet_minus: QIcon
    device_tablet_off: QIcon
    device_tablet_pause: QIcon
    device_tablet_pin: QIcon
    device_tablet_plus: QIcon
    device_tablet_question: QIcon
    device_tablet_search: QIcon
    device_tablet_share: QIcon
    device_tablet_star: QIcon
    device_tablet_up: QIcon
    device_tablet_x: QIcon
    device_tv: QIcon
    device_tv_off: QIcon
    device_tv_old: QIcon
    device_usb: QIcon
    device_vision_pro: QIcon
    device_watch: QIcon
    device_watch_bolt: QIcon
    device_watch_cancel: QIcon
    device_watch_check: QIcon
    device_watch_code: QIcon
    device_watch_cog: QIcon
    device_watch_dollar: QIcon
    device_watch_down: QIcon
    device_watch_exclamation: QIcon
    device_watch_heart: QIcon
    device_watch_minus: QIcon
    device_watch_off: QIcon
    device_watch_pause: QIcon
    device_watch_pin: QIcon
    device_watch_plus: QIcon
    device_watch_question: QIcon
    device_watch_search: QIcon
    device_watch_share: QIcon
    device_watch_star: QIcon
    device_watch_stats: QIcon
    device_watch_stats_2: QIcon
    device_watch_up: QIcon
    device_watch_x: QIcon
    diabolo: QIcon
    diabolo_off: QIcon
    diabolo_plus: QIcon
    dialpad: QIcon
    dialpad_filled: QIcon
    dialpad_off: QIcon
    diamond: QIcon
    diamond_filled: QIcon
    diamond_off: QIcon
    diamonds: QIcon
    diamonds_filled: QIcon
    dice: QIcon
    dice_1: QIcon
    dice_1_filled: QIcon
    dice_2: QIcon
    dice_2_filled: QIcon
    dice_3: QIcon
    dice_3_filled: QIcon
    dice_4: QIcon
    dice_4_filled: QIcon
    dice_5: QIcon
    dice_5_filled: QIcon
    dice_6: QIcon
    dice_6_filled: QIcon
    dice_filled: QIcon
    dimensions: QIcon
    direction: QIcon
    direction_horizontal: QIcon
    directions: QIcon
    direction_sign: QIcon
    direction_sign_filled: QIcon
    direction_sign_off: QIcon
    directions_off: QIcon
    disabled: QIcon
    disabled_2: QIcon
    disabled_off: QIcon
    disc: QIcon
    disc_golf: QIcon
    disc_off: QIcon
    discount: QIcon
    discount_2: QIcon
    discount_2_off: QIcon
    discount_check: QIcon
    discount_check_filled: QIcon
    discount_off: QIcon
    divide: QIcon
    dna: QIcon
    dna_2: QIcon
    dna_2_off: QIcon
    dna_off: QIcon
    dog: QIcon
    dog_bowl: QIcon
    door: QIcon
    door_enter: QIcon
    door_exit: QIcon
    door_off: QIcon
    dots: QIcon
    dots_circle_horizontal: QIcon
    dots_diagonal: QIcon
    dots_diagonal_2: QIcon
    dots_vertical: QIcon
    download: QIcon
    download_off: QIcon
    drag_drop: QIcon
    drag_drop_2: QIcon
    drone: QIcon
    drone_off: QIcon
    drop_circle: QIcon
    droplet: QIcon
    droplet_bolt: QIcon
    droplet_cancel: QIcon
    droplet_check: QIcon
    droplet_code: QIcon
    droplet_cog: QIcon
    droplet_dollar: QIcon
    droplet_down: QIcon
    droplet_exclamation: QIcon
    droplet_filled: QIcon
    droplet_half: QIcon
    droplet_half_2: QIcon
    droplet_half_2_filled: QIcon
    droplet_half_filled: QIcon
    droplet_heart: QIcon
    droplet_minus: QIcon
    droplet_off: QIcon
    droplet_pause: QIcon
    droplet_pin: QIcon
    droplet_plus: QIcon
    droplet_question: QIcon
    droplets: QIcon
    droplet_search: QIcon
    droplet_share: QIcon
    droplet_star: QIcon
    droplet_up: QIcon
    droplet_x: QIcon
    dual_screen: QIcon
    ear: QIcon
    ear_off: QIcon
    ease_in: QIcon
    ease_in_control_point: QIcon
    ease_in_out: QIcon
    ease_in_out_control_points: QIcon
    ease_out: QIcon
    ease_out_control_point: QIcon
    edit: QIcon
    edit_circle: QIcon
    edit_circle_off: QIcon
    edit_off: QIcon
    egg: QIcon
    egg_cracked: QIcon
    egg_filled: QIcon
    egg_fried: QIcon
    egg_off: QIcon
    eggs: QIcon
    elevator: QIcon
    elevator_off: QIcon
    emergency_bed: QIcon
    empathize: QIcon
    empathize_off: QIcon
    emphasis: QIcon
    engine: QIcon
    engine_off: QIcon
    e_passport: QIcon
    equal: QIcon
    equal_double: QIcon
    equal_not: QIcon
    eraser: QIcon
    eraser_off: QIcon
    error_404: QIcon
    error_404_off: QIcon
    escalator: QIcon
    escalator_down: QIcon
    escalator_up: QIcon
    exchange: QIcon
    exchange_off: QIcon
    exclamation_circle: QIcon
    exclamation_mark: QIcon
    exclamation_mark_off: QIcon
    explicit: QIcon
    explicit_off: QIcon
    exposure: QIcon
    exposure_0: QIcon
    exposure_minus_1: QIcon
    exposure_minus_2: QIcon
    exposure_off: QIcon
    exposure_plus_1: QIcon
    exposure_plus_2: QIcon
    external_link: QIcon
    external_link_off: QIcon
    eye: QIcon
    eye_bolt: QIcon
    eye_cancel: QIcon
    eye_check: QIcon
    eye_closed: QIcon
    eye_code: QIcon
    eye_cog: QIcon
    eye_discount: QIcon
    eye_dollar: QIcon
    eye_down: QIcon
    eye_edit: QIcon
    eye_exclamation: QIcon
    eye_filled: QIcon
    eyeglass: QIcon
    eyeglass_2: QIcon
    eyeglass_off: QIcon
    eye_heart: QIcon
    eye_minus: QIcon
    eye_off: QIcon
    eye_pause: QIcon
    eye_pin: QIcon
    eye_plus: QIcon
    eye_question: QIcon
    eye_search: QIcon
    eye_share: QIcon
    eye_star: QIcon
    eye_table: QIcon
    eye_up: QIcon
    eye_x: QIcon
    face_id: QIcon
    face_id_error: QIcon
    face_mask: QIcon
    face_mask_off: QIcon
    fall: QIcon
    feather: QIcon
    feather_off: QIcon
    fence: QIcon
    fence_off: QIcon
    fidget_spinner: QIcon
    file: QIcon
    file_3d: QIcon
    file_alert: QIcon
    file_analytics: QIcon
    file_arrow_left: QIcon
    file_arrow_right: QIcon
    file_barcode: QIcon
    file_broken: QIcon
    file_certificate: QIcon
    file_chart: QIcon
    file_check: QIcon
    file_code: QIcon
    file_code_2: QIcon
    file_cv: QIcon
    file_database: QIcon
    file_delta: QIcon
    file_description: QIcon
    file_diff: QIcon
    file_digit: QIcon
    file_dislike: QIcon
    file_dollar: QIcon
    file_dots: QIcon
    file_download: QIcon
    file_euro: QIcon
    file_export: QIcon
    file_filled: QIcon
    file_function: QIcon
    file_horizontal: QIcon
    file_import: QIcon
    file_infinity: QIcon
    file_info: QIcon
    file_invoice: QIcon
    file_lambda: QIcon
    file_like: QIcon
    file_minus: QIcon
    file_music: QIcon
    file_off: QIcon
    file_orientation: QIcon
    file_pencil: QIcon
    file_percent: QIcon
    file_phone: QIcon
    file_plus: QIcon
    file_power: QIcon
    file_report: QIcon
    file_rss: QIcon
    files: QIcon
    file_scissors: QIcon
    file_search: QIcon
    file_settings: QIcon
    file_shredder: QIcon
    file_signal: QIcon
    files_off: QIcon
    file_spreadsheet: QIcon
    file_stack: QIcon
    file_star: QIcon
    file_symlink: QIcon
    file_text: QIcon
    file_text_ai: QIcon
    file_time: QIcon
    file_type_bmp: QIcon
    file_type_css: QIcon
    file_type_csv: QIcon
    file_type_doc: QIcon
    file_type_docx: QIcon
    file_type_html: QIcon
    file_type_jpg: QIcon
    file_type_js: QIcon
    file_type_jsx: QIcon
    file_type_pdf: QIcon
    file_type_php: QIcon
    file_type_png: QIcon
    file_type_ppt: QIcon
    file_type_rs: QIcon
    file_type_sql: QIcon
    file_type_svg: QIcon
    file_type_ts: QIcon
    file_type_tsx: QIcon
    file_type_txt: QIcon
    file_type_vue: QIcon
    file_type_xls: QIcon
    file_type_xml: QIcon
    file_type_zip: QIcon
    file_typography: QIcon
    file_unknown: QIcon
    file_upload: QIcon
    file_vector: QIcon
    file_x: QIcon
    file_x_filled: QIcon
    file_zip: QIcon
    filter: QIcon
    filter_bolt: QIcon
    filter_cancel: QIcon
    filter_check: QIcon
    filter_code: QIcon
    filter_cog: QIcon
    filter_discount: QIcon
    filter_dollar: QIcon
    filter_down: QIcon
    filter_edit: QIcon
    filter_exclamation: QIcon
    filter_filled: QIcon
    filter_heart: QIcon
    filter_minus: QIcon
    filter_off: QIcon
    filter_pause: QIcon
    filter_pin: QIcon
    filter_plus: QIcon
    filter_question: QIcon
    filters: QIcon
    filter_search: QIcon
    filter_share: QIcon
    filter_star: QIcon
    filter_up: QIcon
    filter_x: QIcon
    fingerprint: QIcon
    fingerprint_off: QIcon
    fire_extinguisher: QIcon
    fire_hydrant: QIcon
    fire_hydrant_off: QIcon
    firetruck: QIcon
    first_aid_kit: QIcon
    first_aid_kit_off: QIcon
    fish: QIcon
    fish_bone: QIcon
    fish_christianity: QIcon
    fish_hook: QIcon
    fish_hook_off: QIcon
    fish_off: QIcon
    flag: QIcon
    flag_2: QIcon
    flag_2_filled: QIcon
    flag_2_off: QIcon
    flag_3: QIcon
    flag_3_filled: QIcon
    flag_bolt: QIcon
    flag_cancel: QIcon
    flag_check: QIcon
    flag_code: QIcon
    flag_cog: QIcon
    flag_discount: QIcon
    flag_dollar: QIcon
    flag_down: QIcon
    flag_exclamation: QIcon
    flag_filled: QIcon
    flag_heart: QIcon
    flag_minus: QIcon
    flag_off: QIcon
    flag_pause: QIcon
    flag_pin: QIcon
    flag_plus: QIcon
    flag_question: QIcon
    flag_search: QIcon
    flag_share: QIcon
    flag_star: QIcon
    flag_up: QIcon
    flag_x: QIcon
    flame: QIcon
    flame_off: QIcon
    flare: QIcon
    flask: QIcon
    flask_2: QIcon
    flask_2_off: QIcon
    flask_off: QIcon
    flip_flops: QIcon
    flip_horizontal: QIcon
    flip_vertical: QIcon
    float_center: QIcon
    float_left: QIcon
    float_none: QIcon
    float_right: QIcon
    flower: QIcon
    flower_off: QIcon
    focus: QIcon
    focus_2: QIcon
    focus_auto: QIcon
    focus_centered: QIcon
    fold: QIcon
    fold_down: QIcon
    folder: QIcon
    folder_bolt: QIcon
    folder_cancel: QIcon
    folder_check: QIcon
    folder_code: QIcon
    folder_cog: QIcon
    folder_dollar: QIcon
    folder_down: QIcon
    folder_exclamation: QIcon
    folder_filled: QIcon
    folder_heart: QIcon
    folder_minus: QIcon
    folder_off: QIcon
    folder_open: QIcon
    folder_pause: QIcon
    folder_pin: QIcon
    folder_plus: QIcon
    folder_question: QIcon
    folders: QIcon
    folder_search: QIcon
    folder_share: QIcon
    folders_off: QIcon
    folder_star: QIcon
    folder_symlink: QIcon
    folder_up: QIcon
    folder_x: QIcon
    fold_up: QIcon
    forbid: QIcon
    forbid_2: QIcon
    forbid_2_filled: QIcon
    forbid_filled: QIcon
    forklift: QIcon
    forms: QIcon
    fountain: QIcon
    fountain_filled: QIcon
    fountain_off: QIcon
    frame: QIcon
    frame_off: QIcon
    free_rights: QIcon
    freeze_column: QIcon
    freeze_row: QIcon
    freeze_row_column: QIcon
    fridge: QIcon
    fridge_off: QIcon
    friends: QIcon
    friends_off: QIcon
    frustum: QIcon
    frustum_off: QIcon
    frustum_plus: QIcon
    function: QIcon
    function_filled: QIcon
    function_off: QIcon
    garden_cart: QIcon
    garden_cart_off: QIcon
    gas_station: QIcon
    gas_station_off: QIcon
    gauge: QIcon
    gauge_filled: QIcon
    gauge_off: QIcon
    gavel: QIcon
    gender_agender: QIcon
    gender_androgyne: QIcon
    gender_bigender: QIcon
    gender_demiboy: QIcon
    gender_demigirl: QIcon
    gender_epicene: QIcon
    gender_female: QIcon
    gender_femme: QIcon
    gender_genderfluid: QIcon
    gender_genderless: QIcon
    gender_genderqueer: QIcon
    gender_hermaphrodite: QIcon
    gender_intergender: QIcon
    gender_male: QIcon
    gender_neutrois: QIcon
    gender_third: QIcon
    gender_transgender: QIcon
    gender_trasvesti: QIcon
    geometry: QIcon
    ghost: QIcon
    ghost_2: QIcon
    ghost_2_filled: QIcon
    ghost_3: QIcon
    ghost_filled: QIcon
    ghost_off: QIcon
    gif: QIcon
    gift: QIcon
    gift_card: QIcon
    gift_card_filled: QIcon
    gift_off: QIcon
    git_branch: QIcon
    git_branch_deleted: QIcon
    git_cherry_pick: QIcon
    git_commit: QIcon
    git_compare: QIcon
    git_fork: QIcon
    git_merge: QIcon
    git_pull_request: QIcon
    git_pull_request_closed: QIcon
    git_pull_request_draft: QIcon
    gizmo: QIcon
    glass: QIcon
    glass_full: QIcon
    glass_full_filled: QIcon
    glass_off: QIcon
    globe: QIcon
    globe_filled: QIcon
    globe_off: QIcon
    go_game: QIcon
    golf: QIcon
    golf_off: QIcon
    gps: QIcon
    gradienter: QIcon
    grain: QIcon
    graph: QIcon
    graph_off: QIcon
    grave: QIcon
    grave_2: QIcon
    grid_dots: QIcon
    grid_pattern: QIcon
    grill: QIcon
    grill_fork: QIcon
    grill_off: QIcon
    grill_spatula: QIcon
    grip_horizontal: QIcon
    grip_vertical: QIcon
    growth: QIcon
    guitar_pick: QIcon
    guitar_pick_filled: QIcon
    h_1: QIcon
    h_2: QIcon
    h_3: QIcon
    h_4: QIcon
    h_5: QIcon
    h_6: QIcon
    hammer: QIcon
    hammer_off: QIcon
    hand_click: QIcon
    hand_finger: QIcon
    hand_finger_off: QIcon
    hand_grab: QIcon
    hand_little_finger: QIcon
    hand_middle_finger: QIcon
    hand_move: QIcon
    hand_off: QIcon
    hand_ring_finger: QIcon
    hand_rock: QIcon
    hand_sanitizer: QIcon
    hand_stop: QIcon
    hand_three_fingers: QIcon
    hand_two_fingers: QIcon
    hanger: QIcon
    hanger_2: QIcon
    hanger_off: QIcon
    hash: QIcon
    haze: QIcon
    haze_moon: QIcon
    hdr: QIcon
    heading: QIcon
    heading_off: QIcon
    headphones: QIcon
    headphones_filled: QIcon
    headphones_off: QIcon
    headset: QIcon
    headset_off: QIcon
    health_recognition: QIcon
    heart: QIcon
    heartbeat: QIcon
    heart_bolt: QIcon
    heart_broken: QIcon
    heart_cancel: QIcon
    heart_check: QIcon
    heart_code: QIcon
    heart_cog: QIcon
    heart_discount: QIcon
    heart_dollar: QIcon
    heart_down: QIcon
    heart_exclamation: QIcon
    heart_filled: QIcon
    heart_handshake: QIcon
    heart_minus: QIcon
    heart_off: QIcon
    heart_pause: QIcon
    heart_pin: QIcon
    heart_plus: QIcon
    heart_question: QIcon
    heart_rate_monitor: QIcon
    hearts: QIcon
    heart_search: QIcon
    heart_share: QIcon
    hearts_off: QIcon
    heart_star: QIcon
    heart_up: QIcon
    heart_x: QIcon
    helicopter: QIcon
    helicopter_landing: QIcon
    helmet: QIcon
    helmet_off: QIcon
    help: QIcon
    help_circle: QIcon
    help_circle_filled: QIcon
    help_hexagon: QIcon
    help_hexagon_filled: QIcon
    help_octagon: QIcon
    help_octagon_filled: QIcon
    help_off: QIcon
    help_small: QIcon
    help_square: QIcon
    help_square_filled: QIcon
    help_square_rounded: QIcon
    help_square_rounded_filled: QIcon
    help_triangle: QIcon
    help_triangle_filled: QIcon
    hemisphere: QIcon
    hemisphere_off: QIcon
    hemisphere_plus: QIcon
    hexagon: QIcon
    hexagon_0_filled: QIcon
    hexagon_1_filled: QIcon
    hexagon_2_filled: QIcon
    hexagon_3d: QIcon
    hexagon_3_filled: QIcon
    hexagon_4_filled: QIcon
    hexagon_5_filled: QIcon
    hexagon_6_filled: QIcon
    hexagon_7_filled: QIcon
    hexagon_8_filled: QIcon
    hexagon_9_filled: QIcon
    hexagonal_prism: QIcon
    hexagonal_prism_off: QIcon
    hexagonal_prism_plus: QIcon
    hexagonal_pyramid: QIcon
    hexagonal_pyramid_off: QIcon
    hexagonal_pyramid_plus: QIcon
    hexagon_filled: QIcon
    hexagon_letter_a: QIcon
    hexagon_letter_b: QIcon
    hexagon_letter_c: QIcon
    hexagon_letter_d: QIcon
    hexagon_letter_e: QIcon
    hexagon_letter_f: QIcon
    hexagon_letter_g: QIcon
    hexagon_letter_h: QIcon
    hexagon_letter_i: QIcon
    hexagon_letter_j: QIcon
    hexagon_letter_k: QIcon
    hexagon_letter_l: QIcon
    hexagon_letter_m: QIcon
    hexagon_letter_n: QIcon
    hexagon_letter_o: QIcon
    hexagon_letter_p: QIcon
    hexagon_letter_q: QIcon
    hexagon_letter_r: QIcon
    hexagon_letter_s: QIcon
    hexagon_letter_t: QIcon
    hexagon_letter_u: QIcon
    hexagon_letter_v: QIcon
    hexagon_letter_w: QIcon
    hexagon_letter_x: QIcon
    hexagon_letter_y: QIcon
    hexagon_letter_z: QIcon
    hexagon_minus: QIcon
    hexagon_minus_2: QIcon
    hexagon_number_0: QIcon
    hexagon_number_1: QIcon
    hexagon_number_2: QIcon
    hexagon_number_3: QIcon
    hexagon_number_4: QIcon
    hexagon_number_5: QIcon
    hexagon_number_6: QIcon
    hexagon_number_7: QIcon
    hexagon_number_8: QIcon
    hexagon_number_9: QIcon
    hexagon_off: QIcon
    hexagon_plus: QIcon
    hexagon_plus_2: QIcon
    hexagons: QIcon
    hexagons_off: QIcon
    hierarchy: QIcon
    hierarchy_2: QIcon
    hierarchy_3: QIcon
    hierarchy_off: QIcon
    highlight: QIcon
    highlight_off: QIcon
    history: QIcon
    history_off: QIcon
    history_toggle: QIcon
    home: QIcon
    home_2: QIcon
    home_bolt: QIcon
    home_cancel: QIcon
    home_check: QIcon
    home_cog: QIcon
    home_dollar: QIcon
    home_dot: QIcon
    home_down: QIcon
    home_eco: QIcon
    home_edit: QIcon
    home_exclamation: QIcon
    home_hand: QIcon
    home_heart: QIcon
    home_infinity: QIcon
    home_link: QIcon
    home_minus: QIcon
    home_move: QIcon
    home_off: QIcon
    home_plus: QIcon
    home_question: QIcon
    home_ribbon: QIcon
    home_search: QIcon
    home_share: QIcon
    home_shield: QIcon
    home_signal: QIcon
    home_star: QIcon
    home_stats: QIcon
    home_up: QIcon
    home_x: QIcon
    horse: QIcon
    horse_toy: QIcon
    hotel_service: QIcon
    hourglass: QIcon
    hourglass_empty: QIcon
    hourglass_filled: QIcon
    hourglass_high: QIcon
    hourglass_low: QIcon
    hourglass_off: QIcon
    html: QIcon
    http_connect: QIcon
    http_delete: QIcon
    http_get: QIcon
    http_head: QIcon
    http_options: QIcon
    http_patch: QIcon
    http_post: QIcon
    http_put: QIcon
    http_que: QIcon
    http_trace: QIcon
    ice_cream: QIcon
    ice_cream_2: QIcon
    ice_cream_off: QIcon
    ice_skating: QIcon
    icons: QIcon
    icons_off: QIcon
    id: QIcon
    id_badge: QIcon
    id_badge_2: QIcon
    id_badge_off: QIcon
    id_off: QIcon
    inbox: QIcon
    inbox_off: QIcon
    indent_decrease: QIcon
    indent_increase: QIcon
    infinity: QIcon
    infinity_off: QIcon
    info_circle: QIcon
    info_circle_filled: QIcon
    info_hexagon: QIcon
    info_hexagon_filled: QIcon
    info_octagon: QIcon
    info_octagon_filled: QIcon
    info_small: QIcon
    info_square: QIcon
    info_square_filled: QIcon
    info_square_rounded: QIcon
    info_square_rounded_filled: QIcon
    info_triangle: QIcon
    info_triangle_filled: QIcon
    inner_shadow_bottom: QIcon
    inner_shadow_bottom_filled: QIcon
    inner_shadow_bottom_left: QIcon
    inner_shadow_bottom_left_filled: QIcon
    inner_shadow_bottom_right: QIcon
    inner_shadow_bottom_right_filled: QIcon
    inner_shadow_left: QIcon
    inner_shadow_left_filled: QIcon
    inner_shadow_right: QIcon
    inner_shadow_right_filled: QIcon
    inner_shadow_top: QIcon
    inner_shadow_top_filled: QIcon
    inner_shadow_top_left: QIcon
    inner_shadow_top_left_filled: QIcon
    inner_shadow_top_right: QIcon
    inner_shadow_top_right_filled: QIcon
    input_ai: QIcon
    input_check: QIcon
    input_search: QIcon
    input_x: QIcon
    ironing: QIcon
    ironing_1: QIcon
    ironing_2: QIcon
    ironing_3: QIcon
    ironing_off: QIcon
    ironing_steam: QIcon
    ironing_steam_off: QIcon
    irregular_polyhedron: QIcon
    irregular_polyhedron_off: QIcon
    irregular_polyhedron_plus: QIcon
    italic: QIcon
    jacket: QIcon
    jetpack: QIcon
    jewish_star: QIcon
    jewish_star_filled: QIcon
    jpg: QIcon
    json: QIcon
    jump_rope: QIcon
    karate: QIcon
    kayak: QIcon
    kering: QIcon
    key: QIcon
    keyboard: QIcon
    keyboard_hide: QIcon
    keyboard_off: QIcon
    keyboard_show: QIcon
    keyframe: QIcon
    keyframe_align_center: QIcon
    keyframe_align_center_filled: QIcon
    keyframe_align_horizontal: QIcon
    keyframe_align_horizontal_filled: QIcon
    keyframe_align_vertical: QIcon
    keyframe_align_vertical_filled: QIcon
    keyframe_filled: QIcon
    keyframes: QIcon
    keyframes_filled: QIcon
    key_off: QIcon
    ladder: QIcon
    ladder_off: QIcon
    ladle: QIcon
    _lambda: QIcon
    lamp: QIcon
    lamp_2: QIcon
    lamp_off: QIcon
    lane: QIcon
    language: QIcon
    language_hiragana: QIcon
    language_katakana: QIcon
    language_off: QIcon
    lasso: QIcon
    lasso_off: QIcon
    lasso_polygon: QIcon
    layers_difference: QIcon
    layers_intersect: QIcon
    layers_intersect_2: QIcon
    layers_linked: QIcon
    layers_off: QIcon
    layers_subtract: QIcon
    layers_union: QIcon
    layout: QIcon
    layout_2: QIcon
    layout_align_bottom: QIcon
    layout_align_center: QIcon
    layout_align_left: QIcon
    layout_align_middle: QIcon
    layout_align_right: QIcon
    layout_align_top: QIcon
    layout_board: QIcon
    layout_board_split: QIcon
    layout_bottombar: QIcon
    layout_bottombar_collapse: QIcon
    layout_bottombar_collapse_filled: QIcon
    layout_bottombar_expand: QIcon
    layout_bottombar_expand_filled: QIcon
    layout_bottombar_filled: QIcon
    layout_cards: QIcon
    layout_collage: QIcon
    layout_columns: QIcon
    layout_dashboard: QIcon
    layout_distribute_horizontal: QIcon
    layout_distribute_vertical: QIcon
    layout_grid: QIcon
    layout_grid_add: QIcon
    layout_grid_remove: QIcon
    layout_kanban: QIcon
    layout_list: QIcon
    layout_navbar: QIcon
    layout_navbar_collapse: QIcon
    layout_navbar_collapse_filled: QIcon
    layout_navbar_expand: QIcon
    layout_navbar_expand_filled: QIcon
    layout_navbar_filled: QIcon
    layout_off: QIcon
    layout_rows: QIcon
    layout_sidebar: QIcon
    layout_sidebar_left_collapse: QIcon
    layout_sidebar_left_collapse_filled: QIcon
    layout_sidebar_left_expand: QIcon
    layout_sidebar_left_expand_filled: QIcon
    layout_sidebar_right: QIcon
    layout_sidebar_right_collapse: QIcon
    layout_sidebar_right_collapse_filled: QIcon
    layout_sidebar_right_expand: QIcon
    layout_sidebar_right_expand_filled: QIcon
    leaf: QIcon
    leaf_off: QIcon
    lego: QIcon
    lego_off: QIcon
    lemon: QIcon
    lemon_2: QIcon
    letter_a: QIcon
    letter_b: QIcon
    letter_c: QIcon
    letter_case: QIcon
    letter_case_lower: QIcon
    letter_case_toggle: QIcon
    letter_case_upper: QIcon
    letter_d: QIcon
    letter_e: QIcon
    letter_f: QIcon
    letter_g: QIcon
    letter_h: QIcon
    letter_i: QIcon
    letter_j: QIcon
    letter_k: QIcon
    letter_l: QIcon
    letter_m: QIcon
    letter_n: QIcon
    letter_o: QIcon
    letter_p: QIcon
    letter_q: QIcon
    letter_r: QIcon
    letter_s: QIcon
    letter_spacing: QIcon
    letter_t: QIcon
    letter_u: QIcon
    letter_v: QIcon
    letter_w: QIcon
    letter_x: QIcon
    letter_y: QIcon
    letter_z: QIcon
    license: QIcon
    license_off: QIcon
    lifebuoy: QIcon
    lifebuoy_off: QIcon
    lighter: QIcon
    line: QIcon
    line_dashed: QIcon
    line_dotted: QIcon
    line_height: QIcon
    link: QIcon
    link_off: QIcon
    list: QIcon
    list_check: QIcon
    list_details: QIcon
    list_letters: QIcon
    list_numbers: QIcon
    list_search: QIcon
    list_tree: QIcon
    live_photo: QIcon
    live_photo_off: QIcon
    live_view: QIcon
    load_balancer: QIcon
    loader: QIcon
    loader_2: QIcon
    loader_3: QIcon
    loader_quarter: QIcon
    location: QIcon
    location_bolt: QIcon
    location_broken: QIcon
    location_cancel: QIcon
    location_check: QIcon
    location_code: QIcon
    location_cog: QIcon
    location_discount: QIcon
    location_dollar: QIcon
    location_down: QIcon
    location_exclamation: QIcon
    location_filled: QIcon
    location_heart: QIcon
    location_minus: QIcon
    location_off: QIcon
    location_pause: QIcon
    location_pin: QIcon
    location_plus: QIcon
    location_question: QIcon
    location_search: QIcon
    location_share: QIcon
    location_star: QIcon
    location_up: QIcon
    location_x: QIcon
    lock: QIcon
    lock_access: QIcon
    lock_access_off: QIcon
    lock_bolt: QIcon
    lock_cancel: QIcon
    lock_check: QIcon
    lock_code: QIcon
    lock_cog: QIcon
    lock_dollar: QIcon
    lock_down: QIcon
    lock_exclamation: QIcon
    lock_heart: QIcon
    lock_minus: QIcon
    lock_off: QIcon
    lock_open: QIcon
    lock_open_off: QIcon
    lock_pause: QIcon
    lock_pin: QIcon
    lock_plus: QIcon
    lock_question: QIcon
    lock_search: QIcon
    lock_share: QIcon
    lock_square: QIcon
    lock_square_rounded: QIcon
    lock_square_rounded_filled: QIcon
    lock_star: QIcon
    lock_up: QIcon
    lock_x: QIcon
    logic_and: QIcon
    logic_buffer: QIcon
    logic_nand: QIcon
    logic_nor: QIcon
    logic_not: QIcon
    logic_or: QIcon
    logic_xnor: QIcon
    logic_xor: QIcon
    login: QIcon
    login_2: QIcon
    logout: QIcon
    logout_2: QIcon
    lollipop: QIcon
    lollipop_off: QIcon
    luggage: QIcon
    luggage_off: QIcon
    lungs: QIcon
    lungs_off: QIcon
    macro: QIcon
    macro_off: QIcon
    magnet: QIcon
    magnet_off: QIcon
    mail: QIcon
    mail_ai: QIcon
    mail_bolt: QIcon
    mailbox: QIcon
    mailbox_off: QIcon
    mail_cancel: QIcon
    mail_check: QIcon
    mail_code: QIcon
    mail_cog: QIcon
    mail_dollar: QIcon
    mail_down: QIcon
    mail_exclamation: QIcon
    mail_fast: QIcon
    mail_filled: QIcon
    mail_forward: QIcon
    mail_heart: QIcon
    mail_minus: QIcon
    mail_off: QIcon
    mail_opened: QIcon
    mail_opened_filled: QIcon
    mail_pause: QIcon
    mail_pin: QIcon
    mail_plus: QIcon
    mail_question: QIcon
    mail_search: QIcon
    mail_share: QIcon
    mail_star: QIcon
    mail_up: QIcon
    mail_x: QIcon
    man: QIcon
    manual_gearbox: QIcon
    map: QIcon
    map_2: QIcon
    map_bolt: QIcon
    map_cancel: QIcon
    map_check: QIcon
    map_code: QIcon
    map_cog: QIcon
    map_discount: QIcon
    map_dollar: QIcon
    map_down: QIcon
    map_east: QIcon
    map_exclamation: QIcon
    map_heart: QIcon
    map_minus: QIcon
    map_north: QIcon
    map_off: QIcon
    map_pause: QIcon
    map_pin: QIcon
    map_pin_2: QIcon
    map_pin_bolt: QIcon
    map_pin_cancel: QIcon
    map_pin_check: QIcon
    map_pin_code: QIcon
    map_pin_cog: QIcon
    map_pin_dollar: QIcon
    map_pin_down: QIcon
    map_pin_exclamation: QIcon
    map_pin_filled: QIcon
    map_pin_heart: QIcon
    map_pin_minus: QIcon
    map_pin_off: QIcon
    map_pin_pause: QIcon
    map_pin_pin: QIcon
    map_pin_plus: QIcon
    map_pin_question: QIcon
    map_pins: QIcon
    map_pin_search: QIcon
    map_pin_share: QIcon
    map_pin_star: QIcon
    map_pin_up: QIcon
    map_pin_x: QIcon
    map_plus: QIcon
    map_question: QIcon
    map_route: QIcon
    map_search: QIcon
    map_share: QIcon
    map_south: QIcon
    map_star: QIcon
    map_up: QIcon
    map_west: QIcon
    map_x: QIcon
    markdown: QIcon
    markdown_off: QIcon
    marquee: QIcon
    marquee_2: QIcon
    marquee_off: QIcon
    mars: QIcon
    mask: QIcon
    mask_off: QIcon
    masks_theater: QIcon
    masks_theater_off: QIcon
    massage: QIcon
    matchstick: QIcon
    math: QIcon
    math_1_divide_2: QIcon
    math_1_divide_3: QIcon
    math_avg: QIcon
    math_equal_greater: QIcon
    math_equal_lower: QIcon
    math_function: QIcon
    math_function_off: QIcon
    math_function_y: QIcon
    math_greater: QIcon
    math_integral: QIcon
    math_integrals: QIcon
    math_integral_x: QIcon
    math_lower: QIcon
    math_max: QIcon
    math_min: QIcon
    math_not: QIcon
    math_off: QIcon
    math_pi: QIcon
    math_pi_divide_2: QIcon
    math_symbols: QIcon
    math_x_divide_2: QIcon
    math_x_divide_y: QIcon
    math_x_divide_y_2: QIcon
    math_x_minus_x: QIcon
    math_x_minus_y: QIcon
    math_x_plus_x: QIcon
    math_x_plus_y: QIcon
    math_xy: QIcon
    math_y_minus_y: QIcon
    math_y_plus_y: QIcon
    maximize: QIcon
    maximize_off: QIcon
    meat: QIcon
    meat_off: QIcon
    medal: QIcon
    medal_2: QIcon
    medical_cross: QIcon
    medical_cross_circle: QIcon
    medical_cross_filled: QIcon
    medical_cross_off: QIcon
    medicine_syrup: QIcon
    meeple: QIcon
    melon: QIcon
    menorah: QIcon
    menu: QIcon
    menu_2: QIcon
    menu_deep: QIcon
    menu_order: QIcon
    message: QIcon
    message_2: QIcon
    message_2_bolt: QIcon
    message_2_cancel: QIcon
    message_2_check: QIcon
    message_2_code: QIcon
    message_2_cog: QIcon
    message_2_dollar: QIcon
    message_2_down: QIcon
    message_2_exclamation: QIcon
    message_2_heart: QIcon
    message_2_minus: QIcon
    message_2_off: QIcon
    message_2_pause: QIcon
    message_2_pin: QIcon
    message_2_plus: QIcon
    message_2_question: QIcon
    message_2_search: QIcon
    message_2_share: QIcon
    message_2_star: QIcon
    message_2_up: QIcon
    message_2_x: QIcon
    message_bolt: QIcon
    message_cancel: QIcon
    message_chatbot: QIcon
    message_check: QIcon
    message_circle: QIcon
    message_circle_2: QIcon
    message_circle_2_filled: QIcon
    message_circle_bolt: QIcon
    message_circle_cancel: QIcon
    message_circle_check: QIcon
    message_circle_code: QIcon
    message_circle_cog: QIcon
    message_circle_dollar: QIcon
    message_circle_down: QIcon
    message_circle_exclamation: QIcon
    message_circle_heart: QIcon
    message_circle_minus: QIcon
    message_circle_off: QIcon
    message_circle_pause: QIcon
    message_circle_pin: QIcon
    message_circle_plus: QIcon
    message_circle_question: QIcon
    message_circle_search: QIcon
    message_circle_share: QIcon
    message_circle_star: QIcon
    message_circle_up: QIcon
    message_circle_x: QIcon
    message_code: QIcon
    message_cog: QIcon
    message_dollar: QIcon
    message_dots: QIcon
    message_down: QIcon
    message_exclamation: QIcon
    message_forward: QIcon
    message_heart: QIcon
    message_language: QIcon
    message_minus: QIcon
    message_off: QIcon
    message_pause: QIcon
    message_pin: QIcon
    message_plus: QIcon
    message_question: QIcon
    message_report: QIcon
    messages: QIcon
    message_search: QIcon
    message_share: QIcon
    messages_off: QIcon
    message_star: QIcon
    message_up: QIcon
    message_x: QIcon
    meteor: QIcon
    meteor_off: QIcon
    michelin_bib_gourmand: QIcon
    michelin_star: QIcon
    michelin_star_green: QIcon
    mickey: QIcon
    mickey_filled: QIcon
    microphone: QIcon
    microphone_2: QIcon
    microphone_2_off: QIcon
    microphone_off: QIcon
    microscope: QIcon
    microscope_off: QIcon
    microwave: QIcon
    microwave_off: QIcon
    military_award: QIcon
    military_rank: QIcon
    milk: QIcon
    milk_off: QIcon
    milkshake: QIcon
    minimize: QIcon
    minus: QIcon
    minus_vertical: QIcon
    mist: QIcon
    mist_off: QIcon
    mobiledata: QIcon
    mobiledata_off: QIcon
    moneybag: QIcon
    mood_angry: QIcon
    mood_annoyed: QIcon
    mood_annoyed_2: QIcon
    mood_boy: QIcon
    mood_check: QIcon
    mood_cog: QIcon
    mood_confuzed: QIcon
    mood_confuzed_filled: QIcon
    mood_crazy_happy: QIcon
    mood_cry: QIcon
    mood_dollar: QIcon
    mood_edit: QIcon
    mood_empty: QIcon
    mood_empty_filled: QIcon
    mood_happy: QIcon
    mood_happy_filled: QIcon
    mood_heart: QIcon
    mood_kid: QIcon
    mood_kid_filled: QIcon
    mood_look_left: QIcon
    mood_look_right: QIcon
    mood_minus: QIcon
    mood_nerd: QIcon
    mood_nervous: QIcon
    mood_neutral: QIcon
    mood_neutral_filled: QIcon
    mood_off: QIcon
    mood_pin: QIcon
    mood_plus: QIcon
    mood_sad: QIcon
    mood_sad_2: QIcon
    mood_sad_dizzy: QIcon
    mood_sad_filled: QIcon
    mood_sad_squint: QIcon
    mood_search: QIcon
    mood_share: QIcon
    mood_sick: QIcon
    mood_silence: QIcon
    mood_sing: QIcon
    mood_smile: QIcon
    mood_smile_beam: QIcon
    mood_smile_dizzy: QIcon
    mood_smile_filled: QIcon
    mood_suprised: QIcon
    mood_tongue: QIcon
    mood_tongue_wink: QIcon
    mood_tongue_wink_2: QIcon
    mood_unamused: QIcon
    mood_up: QIcon
    mood_wink: QIcon
    mood_wink_2: QIcon
    mood_wrrr: QIcon
    mood_x: QIcon
    mood_xd: QIcon
    moon: QIcon
    moon_2: QIcon
    moon_filled: QIcon
    moon_off: QIcon
    moon_stars: QIcon
    moped: QIcon
    motorbike: QIcon
    mountain: QIcon
    mountain_off: QIcon
    mouse: QIcon
    mouse_2: QIcon
    mouse_filled: QIcon
    mouse_off: QIcon
    moustache: QIcon
    movie: QIcon
    movie_off: QIcon
    mug: QIcon
    mug_off: QIcon
    multiplier_0_5x: QIcon
    multiplier_1_5x: QIcon
    multiplier_1x: QIcon
    multiplier_2x: QIcon
    mushroom: QIcon
    mushroom_filled: QIcon
    mushroom_off: QIcon
    music: QIcon
    music_bolt: QIcon
    music_cancel: QIcon
    music_check: QIcon
    music_code: QIcon
    music_cog: QIcon
    music_discount: QIcon
    music_dollar: QIcon
    music_down: QIcon
    music_exclamation: QIcon
    music_heart: QIcon
    music_minus: QIcon
    music_off: QIcon
    music_pause: QIcon
    music_pin: QIcon
    music_plus: QIcon
    music_question: QIcon
    music_search: QIcon
    music_share: QIcon
    music_star: QIcon
    music_up: QIcon
    music_x: QIcon
    navigation: QIcon
    navigation_bolt: QIcon
    navigation_cancel: QIcon
    navigation_check: QIcon
    navigation_code: QIcon
    navigation_cog: QIcon
    navigation_discount: QIcon
    navigation_dollar: QIcon
    navigation_down: QIcon
    navigation_exclamation: QIcon
    navigation_filled: QIcon
    navigation_heart: QIcon
    navigation_minus: QIcon
    navigation_north: QIcon
    navigation_off: QIcon
    navigation_pause: QIcon
    navigation_pin: QIcon
    navigation_plus: QIcon
    navigation_question: QIcon
    navigation_search: QIcon
    navigation_share: QIcon
    navigation_star: QIcon
    navigation_up: QIcon
    navigation_x: QIcon
    needle: QIcon
    needle_thread: QIcon
    network: QIcon
    network_off: QIcon
    news: QIcon
    new_section: QIcon
    news_off: QIcon
    nfc: QIcon
    nfc_off: QIcon
    no_copyright: QIcon
    no_creative_commons: QIcon
    no_derivatives: QIcon
    north_star: QIcon
    note: QIcon
    notebook: QIcon
    notebook_off: QIcon
    note_off: QIcon
    notes: QIcon
    notes_off: QIcon
    notification: QIcon
    notification_off: QIcon
    number: QIcon
    number_0: QIcon
    number_1: QIcon
    number_2: QIcon
    number_3: QIcon
    number_4: QIcon
    number_5: QIcon
    number_6: QIcon
    number_7: QIcon
    number_8: QIcon
    number_9: QIcon
    numbers: QIcon
    nurse: QIcon
    nut: QIcon
    octagon: QIcon
    octagon_filled: QIcon
    octagon_minus: QIcon
    octagon_minus_2: QIcon
    octagon_off: QIcon
    octagon_plus: QIcon
    octagon_plus_2: QIcon
    octahedron: QIcon
    octahedron_off: QIcon
    octahedron_plus: QIcon
    old: QIcon
    olympics: QIcon
    olympics_off: QIcon
    om: QIcon
    omega: QIcon
    outbound: QIcon
    outlet: QIcon
    oval: QIcon
    oval_filled: QIcon
    oval_vertical: QIcon
    oval_vertical_filled: QIcon
    overline: QIcon
    package: QIcon
    package_export: QIcon
    package_import: QIcon
    package_off: QIcon
    packages: QIcon
    pacman: QIcon
    page_break: QIcon
    paint: QIcon
    paint_filled: QIcon
    paint_off: QIcon
    palette: QIcon
    palette_off: QIcon
    panorama_horizontal: QIcon
    panorama_horizontal_off: QIcon
    panorama_vertical: QIcon
    panorama_vertical_off: QIcon
    paper_bag: QIcon
    paper_bag_off: QIcon
    paperclip: QIcon
    parachute: QIcon
    parachute_off: QIcon
    parentheses: QIcon
    parentheses_off: QIcon
    parking: QIcon
    parking_off: QIcon
    password: QIcon
    password_fingerprint: QIcon
    password_mobile_phone: QIcon
    password_user: QIcon
    paw: QIcon
    paw_filled: QIcon
    paw_off: QIcon
    pdf: QIcon
    peace: QIcon
    pencil: QIcon
    pencil_bolt: QIcon
    pencil_cancel: QIcon
    pencil_check: QIcon
    pencil_code: QIcon
    pencil_cog: QIcon
    pencil_discount: QIcon
    pencil_dollar: QIcon
    pencil_down: QIcon
    pencil_exclamation: QIcon
    pencil_heart: QIcon
    pencil_minus: QIcon
    pencil_off: QIcon
    pencil_pause: QIcon
    pencil_pin: QIcon
    pencil_plus: QIcon
    pencil_question: QIcon
    pencil_search: QIcon
    pencil_share: QIcon
    pencil_star: QIcon
    pencil_up: QIcon
    pencil_x: QIcon
    pennant: QIcon
    pennant_2: QIcon
    pennant_2_filled: QIcon
    pennant_filled: QIcon
    pennant_off: QIcon
    pentagon: QIcon
    pentagon_filled: QIcon
    pentagon_number_0: QIcon
    pentagon_number_1: QIcon
    pentagon_number_2: QIcon
    pentagon_number_3: QIcon
    pentagon_number_4: QIcon
    pentagon_number_5: QIcon
    pentagon_number_6: QIcon
    pentagon_number_7: QIcon
    pentagon_number_8: QIcon
    pentagon_number_9: QIcon
    pentagon_off: QIcon
    pentagon_plus: QIcon
    pentagon_x: QIcon
    pentagram: QIcon
    pepper: QIcon
    pepper_off: QIcon
    percentage: QIcon
    perfume: QIcon
    perspective: QIcon
    perspective_off: QIcon
    phone: QIcon
    phone_call: QIcon
    phone_calling: QIcon
    phone_check: QIcon
    phone_filled: QIcon
    phone_incoming: QIcon
    phone_off: QIcon
    phone_outgoing: QIcon
    phone_pause: QIcon
    phone_plus: QIcon
    phone_x: QIcon
    photo: QIcon
    photo_ai: QIcon
    photo_bolt: QIcon
    photo_cancel: QIcon
    photo_check: QIcon
    photo_circle: QIcon
    photo_circle_minus: QIcon
    photo_circle_plus: QIcon
    photo_code: QIcon
    photo_cog: QIcon
    photo_dollar: QIcon
    photo_down: QIcon
    photo_edit: QIcon
    photo_exclamation: QIcon
    photo_filled: QIcon
    photo_heart: QIcon
    photo_hexagon: QIcon
    photo_minus: QIcon
    photo_off: QIcon
    photo_pause: QIcon
    photo_pentagon: QIcon
    photo_pin: QIcon
    photo_plus: QIcon
    photo_question: QIcon
    photo_search: QIcon
    photo_sensor: QIcon
    photo_sensor_2: QIcon
    photo_sensor_3: QIcon
    photo_share: QIcon
    photo_shield: QIcon
    photo_square_rounded: QIcon
    photo_star: QIcon
    photo_up: QIcon
    photo_video: QIcon
    photo_x: QIcon
    physotherapist: QIcon
    piano: QIcon
    pick: QIcon
    picture_in_picture: QIcon
    picture_in_picture_off: QIcon
    picture_in_picture_on: QIcon
    picture_in_picture_top: QIcon
    pig: QIcon
    pig_money: QIcon
    pig_off: QIcon
    pilcrow: QIcon
    pill: QIcon
    pill_off: QIcon
    pills: QIcon
    pin: QIcon
    pin_filled: QIcon
    ping_pong: QIcon
    pinned: QIcon
    pinned_filled: QIcon
    pinned_off: QIcon
    pizza: QIcon
    pizza_off: QIcon
    placeholder: QIcon
    plane: QIcon
    plane_arrival: QIcon
    plane_departure: QIcon
    plane_inflight: QIcon
    plane_off: QIcon
    planet: QIcon
    plane_tilt: QIcon
    planet_off: QIcon
    plant: QIcon
    plant_2: QIcon
    plant_2_off: QIcon
    plant_off: QIcon
    play_basketball: QIcon
    play_card: QIcon
    play_card_off: QIcon
    player_eject: QIcon
    player_eject_filled: QIcon
    player_pause: QIcon
    player_pause_filled: QIcon
    player_play: QIcon
    player_play_filled: QIcon
    player_record: QIcon
    player_record_filled: QIcon
    player_skip_back: QIcon
    player_skip_back_filled: QIcon
    player_skip_forward: QIcon
    player_skip_forward_filled: QIcon
    player_stop: QIcon
    player_stop_filled: QIcon
    player_track_next: QIcon
    player_track_next_filled: QIcon
    player_track_prev: QIcon
    player_track_prev_filled: QIcon
    play_football: QIcon
    play_handball: QIcon
    playlist: QIcon
    playlist_add: QIcon
    playlist_off: QIcon
    playlist_x: QIcon
    playstation_circle: QIcon
    playstation_square: QIcon
    playstation_triangle: QIcon
    playstation_x: QIcon
    play_volleyball: QIcon
    plug: QIcon
    plug_connected: QIcon
    plug_connected_x: QIcon
    plug_off: QIcon
    plug_x: QIcon
    plus: QIcon
    plus_equal: QIcon
    plus_minus: QIcon
    png: QIcon
    podium: QIcon
    podium_off: QIcon
    point: QIcon
    pointer: QIcon
    pointer_bolt: QIcon
    pointer_cancel: QIcon
    pointer_check: QIcon
    pointer_code: QIcon
    pointer_cog: QIcon
    pointer_dollar: QIcon
    pointer_down: QIcon
    pointer_exclamation: QIcon
    pointer_filled: QIcon
    pointer_heart: QIcon
    pointer_minus: QIcon
    pointer_off: QIcon
    pointer_pause: QIcon
    pointer_pin: QIcon
    pointer_plus: QIcon
    pointer_question: QIcon
    pointer_search: QIcon
    pointer_share: QIcon
    pointer_star: QIcon
    pointer_up: QIcon
    pointer_x: QIcon
    point_filled: QIcon
    point_off: QIcon
    pokeball: QIcon
    pokeball_off: QIcon
    poker_chip: QIcon
    polaroid: QIcon
    polaroid_filled: QIcon
    polygon: QIcon
    polygon_off: QIcon
    poo: QIcon
    pool: QIcon
    pool_off: QIcon
    power: QIcon
    pray: QIcon
    premium_rights: QIcon
    prescription: QIcon
    presentation: QIcon
    presentation_analytics: QIcon
    presentation_off: QIcon
    printer: QIcon
    printer_off: QIcon
    prism: QIcon
    prism_off: QIcon
    prism_plus: QIcon
    prison: QIcon
    progress: QIcon
    progress_alert: QIcon
    progress_bolt: QIcon
    progress_check: QIcon
    progress_down: QIcon
    progress_help: QIcon
    progress_x: QIcon
    prompt: QIcon
    propeller: QIcon
    propeller_off: QIcon
    pumpkin_scary: QIcon
    puzzle: QIcon
    puzzle_2: QIcon
    puzzle_filled: QIcon
    puzzle_off: QIcon
    pyramid: QIcon
    pyramid_off: QIcon
    pyramid_plus: QIcon
    qrcode: QIcon
    qrcode_off: QIcon
    question_mark: QIcon
    quote: QIcon
    quote_off: QIcon
    quotes: QIcon
    radar: QIcon
    radar_2: QIcon
    radar_off: QIcon
    radio: QIcon
    radioactive: QIcon
    radioactive_filled: QIcon
    radioactive_off: QIcon
    radio_off: QIcon
    radius_bottom_left: QIcon
    radius_bottom_right: QIcon
    radius_top_left: QIcon
    radius_top_right: QIcon
    rainbow: QIcon
    rainbow_off: QIcon
    rating_12_plus: QIcon
    rating_14_plus: QIcon
    rating_16_plus: QIcon
    rating_18_plus: QIcon
    rating_21_plus: QIcon
    razor: QIcon
    razor_electric: QIcon
    receipt: QIcon
    receipt_2: QIcon
    receipt_off: QIcon
    receipt_refund: QIcon
    receipt_tax: QIcon
    recharging: QIcon
    record_mail: QIcon
    record_mail_off: QIcon
    rectangle: QIcon
    rectangle_filled: QIcon
    rectangle_rounded_bottom: QIcon
    rectangle_rounded_top: QIcon
    rectangle_vertical: QIcon
    rectangle_vertical_filled: QIcon
    rectangular_prism: QIcon
    rectangular_prism_off: QIcon
    rectangular_prism_plus: QIcon
    recycle: QIcon
    recycle_off: QIcon
    refresh: QIcon
    refresh_alert: QIcon
    refresh_dot: QIcon
    refresh_off: QIcon
    regex: QIcon
    regex_off: QIcon
    registered: QIcon
    relation_many_to_many: QIcon
    relation_one_to_many: QIcon
    relation_one_to_one: QIcon
    reload: QIcon
    reorder: QIcon
    repeat: QIcon
    repeat_off: QIcon
    repeat_once: QIcon
    replace: QIcon
    replace_filled: QIcon
    replace_off: QIcon
    report: QIcon
    report_analytics: QIcon
    report_medical: QIcon
    report_money: QIcon
    report_off: QIcon
    report_search: QIcon
    reserved_line: QIcon
    resize: QIcon
    restore: QIcon
    rewind_backward_10: QIcon
    rewind_backward_15: QIcon
    rewind_backward_20: QIcon
    rewind_backward_30: QIcon
    rewind_backward_40: QIcon
    rewind_backward_5: QIcon
    rewind_backward_50: QIcon
    rewind_backward_60: QIcon
    rewind_forward_10: QIcon
    rewind_forward_15: QIcon
    rewind_forward_20: QIcon
    rewind_forward_30: QIcon
    rewind_forward_40: QIcon
    rewind_forward_5: QIcon
    rewind_forward_50: QIcon
    rewind_forward_60: QIcon
    ribbon_health: QIcon
    rings: QIcon
    ripple: QIcon
    ripple_off: QIcon
    road: QIcon
    road_off: QIcon
    road_sign: QIcon
    robot: QIcon
    robot_off: QIcon
    rocket: QIcon
    rocket_off: QIcon
    rollercoaster: QIcon
    rollercoaster_off: QIcon
    roller_skating: QIcon
    rosette: QIcon
    rosette_filled: QIcon
    rosette_number_0: QIcon
    rosette_number_1: QIcon
    rosette_number_2: QIcon
    rosette_number_3: QIcon
    rosette_number_4: QIcon
    rosette_number_5: QIcon
    rosette_number_6: QIcon
    rosette_number_7: QIcon
    rosette_number_8: QIcon
    rosette_number_9: QIcon
    rotate: QIcon
    rotate_2: QIcon
    rotate_360: QIcon
    rotate_clockwise: QIcon
    rotate_clockwise_2: QIcon
    rotate_dot: QIcon
    rotate_rectangle: QIcon
    route: QIcon
    route_2: QIcon
    route_off: QIcon
    router: QIcon
    router_off: QIcon
    row_insert_bottom: QIcon
    row_insert_top: QIcon
    row_remove: QIcon
    rss: QIcon
    rubber_stamp: QIcon
    rubber_stamp_off: QIcon
    ruler: QIcon
    ruler_2: QIcon
    ruler_2_off: QIcon
    ruler_3: QIcon
    ruler_measure: QIcon
    ruler_off: QIcon
    run: QIcon
    sailboat: QIcon
    sailboat_2: QIcon
    sailboat_off: QIcon
    salad: QIcon
    salt: QIcon
    satellite: QIcon
    satellite_off: QIcon
    sausage: QIcon
    scale: QIcon
    scale_off: QIcon
    scale_outline: QIcon
    scale_outline_off: QIcon
    scan: QIcon
    scan_eye: QIcon
    schema: QIcon
    schema_off: QIcon
    school: QIcon
    school_bell: QIcon
    school_off: QIcon
    scissors: QIcon
    scissors_off: QIcon
    scooter: QIcon
    scooter_electric: QIcon
    scoreboard: QIcon
    screen_share: QIcon
    screen_share_off: QIcon
    screenshot: QIcon
    scribble: QIcon
    scribble_off: QIcon
    script: QIcon
    script_minus: QIcon
    script_plus: QIcon
    script_x: QIcon
    scuba_mask: QIcon
    scuba_mask_off: QIcon
    sdk: QIcon
    search: QIcon
    search_off: QIcon
    section: QIcon
    section_sign: QIcon
    seeding: QIcon
    seeding_off: QIcon
    select: QIcon
    select_all: QIcon
    selector: QIcon
    send: QIcon
    send_off: QIcon
    seo: QIcon
    separator: QIcon
    separator_horizontal: QIcon
    separator_vertical: QIcon
    server: QIcon
    server_2: QIcon
    server_bolt: QIcon
    server_cog: QIcon
    server_off: QIcon
    servicemark: QIcon
    settings: QIcon
    settings_2: QIcon
    settings_automation: QIcon
    settings_bolt: QIcon
    settings_cancel: QIcon
    settings_check: QIcon
    settings_code: QIcon
    settings_cog: QIcon
    settings_dollar: QIcon
    settings_down: QIcon
    settings_exclamation: QIcon
    settings_filled: QIcon
    settings_heart: QIcon
    settings_minus: QIcon
    settings_off: QIcon
    settings_pause: QIcon
    settings_pin: QIcon
    settings_plus: QIcon
    settings_question: QIcon
    settings_search: QIcon
    settings_share: QIcon
    settings_star: QIcon
    settings_up: QIcon
    settings_x: QIcon
    shadow: QIcon
    shadow_off: QIcon
    shape: QIcon
    shape_2: QIcon
    shape_3: QIcon
    shape_off: QIcon
    share: QIcon
    share_2: QIcon
    share_3: QIcon
    share_off: QIcon
    shield: QIcon
    shield_bolt: QIcon
    shield_cancel: QIcon
    shield_check: QIcon
    shield_checkered: QIcon
    shield_checkered_filled: QIcon
    shield_check_filled: QIcon
    shield_chevron: QIcon
    shield_code: QIcon
    shield_cog: QIcon
    shield_dollar: QIcon
    shield_down: QIcon
    shield_exclamation: QIcon
    shield_filled: QIcon
    shield_half: QIcon
    shield_half_filled: QIcon
    shield_heart: QIcon
    shield_lock: QIcon
    shield_lock_filled: QIcon
    shield_minus: QIcon
    shield_off: QIcon
    shield_pause: QIcon
    shield_pin: QIcon
    shield_plus: QIcon
    shield_question: QIcon
    shield_search: QIcon
    shield_share: QIcon
    shield_star: QIcon
    shield_up: QIcon
    shield_x: QIcon
    shi_jumping: QIcon
    ship: QIcon
    ship_off: QIcon
    shirt: QIcon
    shirt_filled: QIcon
    shirt_off: QIcon
    shirt_sport: QIcon
    shoe: QIcon
    shoe_off: QIcon
    shopping_bag: QIcon
    shopping_bag_check: QIcon
    shopping_bag_discount: QIcon
    shopping_bag_edit: QIcon
    shopping_bag_exclamation: QIcon
    shopping_bag_minus: QIcon
    shopping_bag_plus: QIcon
    shopping_bag_search: QIcon
    shopping_bag_x: QIcon
    shopping_cart: QIcon
    shopping_cart_bolt: QIcon
    shopping_cart_cancel: QIcon
    shopping_cart_check: QIcon
    shopping_cart_code: QIcon
    shopping_cart_cog: QIcon
    shopping_cart_copy: QIcon
    shopping_cart_discount: QIcon
    shopping_cart_dollar: QIcon
    shopping_cart_down: QIcon
    shopping_cart_exclamation: QIcon
    shopping_cart_filled: QIcon
    shopping_cart_heart: QIcon
    shopping_cart_minus: QIcon
    shopping_cart_off: QIcon
    shopping_cart_pause: QIcon
    shopping_cart_pin: QIcon
    shopping_cart_plus: QIcon
    shopping_cart_question: QIcon
    shopping_cart_search: QIcon
    shopping_cart_share: QIcon
    shopping_cart_star: QIcon
    shopping_cart_up: QIcon
    shopping_cart_x: QIcon
    shovel: QIcon
    shredder: QIcon
    signal_2g: QIcon
    signal_3g: QIcon
    signal_4g: QIcon
    signal_4g_plus: QIcon
    signal_5g: QIcon
    signal_6g: QIcon
    signal_e: QIcon
    signal_g: QIcon
    signal_h: QIcon
    signal_h_plus: QIcon
    signal_lte: QIcon
    signature: QIcon
    signature_off: QIcon
    sign_left: QIcon
    sign_left_filled: QIcon
    sign_right: QIcon
    sign_right_filled: QIcon
    sitemap: QIcon
    sitemap_off: QIcon
    skateboard: QIcon
    skateboarding: QIcon
    skateboard_off: QIcon
    skull: QIcon
    slash: QIcon
    slashes: QIcon
    sleigh: QIcon
    slice: QIcon
    slideshow: QIcon
    smart_home: QIcon
    smart_home_off: QIcon
    smoking: QIcon
    smoking_no: QIcon
    snowflake: QIcon
    snowflake_off: QIcon
    snowman: QIcon
    soccer_field: QIcon
    social: QIcon
    social_off: QIcon
    sock: QIcon
    sofa: QIcon
    sofa_off: QIcon
    solar_panel: QIcon
    solar_panel_2: QIcon
    sort_0_9: QIcon
    sort_9_0: QIcon
    sort_ascending: QIcon
    sort_ascending_2: QIcon
    sort_ascending_letters: QIcon
    sort_ascending_numbers: QIcon
    sort_a_z: QIcon
    sort_descending: QIcon
    sort_descending_2: QIcon
    sort_descending_letters: QIcon
    sort_descending_numbers: QIcon
    sort_z_a: QIcon
    sos: QIcon
    soup: QIcon
    soup_off: QIcon
    source_code: QIcon
    space: QIcon
    space_off: QIcon
    spacing_horizontal: QIcon
    spacing_vertical: QIcon
    spade: QIcon
    spade_filled: QIcon
    sparkles: QIcon
    speakerphone: QIcon
    speedboat: QIcon
    sphere: QIcon
    sphere_off: QIcon
    sphere_plus: QIcon
    spider: QIcon
    spiral: QIcon
    spiral_off: QIcon
    sport_billard: QIcon
    spray: QIcon
    spy: QIcon
    spy_off: QIcon
    sql: QIcon
    square: QIcon
    square_0_filled: QIcon
    square_1_filled: QIcon
    square_2_filled: QIcon
    square_3_filled: QIcon
    square_4_filled: QIcon
    square_5_filled: QIcon
    square_6_filled: QIcon
    square_7_filled: QIcon
    square_8_filled: QIcon
    square_9_filled: QIcon
    square_arrow_down: QIcon
    square_arrow_down_filled: QIcon
    square_arrow_left: QIcon
    square_arrow_left_filled: QIcon
    square_arrow_right: QIcon
    square_arrow_right_filled: QIcon
    square_arrow_up: QIcon
    square_arrow_up_filled: QIcon
    square_asterisk: QIcon
    square_asterisk_filled: QIcon
    square_check: QIcon
    square_check_filled: QIcon
    square_chevron_down: QIcon
    square_chevron_down_filled: QIcon
    square_chevron_left: QIcon
    square_chevron_left_filled: QIcon
    square_chevron_right: QIcon
    square_chevron_right_filled: QIcon
    square_chevrons_down: QIcon
    square_chevrons_down_filled: QIcon
    square_chevrons_left: QIcon
    square_chevrons_left_filled: QIcon
    square_chevrons_right: QIcon
    square_chevrons_right_filled: QIcon
    square_chevrons_up: QIcon
    square_chevrons_up_filled: QIcon
    square_chevron_up: QIcon
    square_chevron_up_filled: QIcon
    square_dot: QIcon
    square_dot_filled: QIcon
    square_f0: QIcon
    square_f0_filled: QIcon
    square_f1: QIcon
    square_f1_filled: QIcon
    square_f2: QIcon
    square_f2_filled: QIcon
    square_f3: QIcon
    square_f3_filled: QIcon
    square_f4: QIcon
    square_f4_filled: QIcon
    square_f5: QIcon
    square_f5_filled: QIcon
    square_f6: QIcon
    square_f6_filled: QIcon
    square_f7: QIcon
    square_f7_filled: QIcon
    square_f8: QIcon
    square_f8_filled: QIcon
    square_f9: QIcon
    square_f9_filled: QIcon
    square_filled: QIcon
    square_forbid: QIcon
    square_forbid_2: QIcon
    square_half: QIcon
    square_key: QIcon
    square_letter_a: QIcon
    square_letter_b: QIcon
    square_letter_c: QIcon
    square_letter_d: QIcon
    square_letter_e: QIcon
    square_letter_f: QIcon
    square_letter_g: QIcon
    square_letter_h: QIcon
    square_letter_i: QIcon
    square_letter_j: QIcon
    square_letter_k: QIcon
    square_letter_l: QIcon
    square_letter_m: QIcon
    square_letter_n: QIcon
    square_letter_o: QIcon
    square_letter_p: QIcon
    square_letter_q: QIcon
    square_letter_r: QIcon
    square_letter_s: QIcon
    square_letter_t: QIcon
    square_letter_u: QIcon
    square_letter_v: QIcon
    square_letter_w: QIcon
    square_letter_x: QIcon
    square_letter_y: QIcon
    square_letter_z: QIcon
    square_minus: QIcon
    square_minus_filled: QIcon
    square_number_0: QIcon
    square_number_1: QIcon
    square_number_2: QIcon
    square_number_3: QIcon
    square_number_4: QIcon
    square_number_5: QIcon
    square_number_6: QIcon
    square_number_7: QIcon
    square_number_8: QIcon
    square_number_9: QIcon
    square_off: QIcon
    square_plus: QIcon
    square_plus_2: QIcon
    square_root: QIcon
    square_root_2: QIcon
    square_rotated: QIcon
    square_rotated_filled: QIcon
    square_rotated_forbid: QIcon
    square_rotated_forbid_2: QIcon
    square_rotated_off: QIcon
    square_rounded: QIcon
    square_rounded_arrow_down: QIcon
    square_rounded_arrow_down_filled: QIcon
    square_rounded_arrow_left: QIcon
    square_rounded_arrow_left_filled: QIcon
    square_rounded_arrow_right: QIcon
    square_rounded_arrow_right_filled: QIcon
    square_rounded_arrow_up: QIcon
    square_rounded_arrow_up_filled: QIcon
    square_rounded_check: QIcon
    square_rounded_check_filled: QIcon
    square_rounded_chevron_down: QIcon
    square_rounded_chevron_down_filled: QIcon
    square_rounded_chevron_left: QIcon
    square_rounded_chevron_left_filled: QIcon
    square_rounded_chevron_right: QIcon
    square_rounded_chevron_right_filled: QIcon
    square_rounded_chevrons_down: QIcon
    square_rounded_chevrons_down_filled: QIcon
    square_rounded_chevrons_left: QIcon
    square_rounded_chevrons_left_filled: QIcon
    square_rounded_chevrons_right: QIcon
    square_rounded_chevrons_right_filled: QIcon
    square_rounded_chevrons_up: QIcon
    square_rounded_chevrons_up_filled: QIcon
    square_rounded_chevron_up: QIcon
    square_rounded_chevron_up_filled: QIcon
    square_rounded_filled: QIcon
    square_rounded_letter_a: QIcon
    square_rounded_letter_b: QIcon
    square_rounded_letter_c: QIcon
    square_rounded_letter_d: QIcon
    square_rounded_letter_e: QIcon
    square_rounded_letter_f: QIcon
    square_rounded_letter_g: QIcon
    square_rounded_letter_h: QIcon
    square_rounded_letter_i: QIcon
    square_rounded_letter_j: QIcon
    square_rounded_letter_k: QIcon
    square_rounded_letter_l: QIcon
    square_rounded_letter_m: QIcon
    square_rounded_letter_n: QIcon
    square_rounded_letter_o: QIcon
    square_rounded_letter_p: QIcon
    square_rounded_letter_q: QIcon
    square_rounded_letter_r: QIcon
    square_rounded_letter_s: QIcon
    square_rounded_letter_t: QIcon
    square_rounded_letter_u: QIcon
    square_rounded_letter_v: QIcon
    square_rounded_letter_w: QIcon
    square_rounded_letter_x: QIcon
    square_rounded_letter_y: QIcon
    square_rounded_letter_z: QIcon
    square_rounded_minus: QIcon
    square_rounded_minus_2: QIcon
    square_rounded_minus_filled: QIcon
    square_rounded_number_0: QIcon
    square_rounded_number_0_filled: QIcon
    square_rounded_number_1: QIcon
    square_rounded_number_1_filled: QIcon
    square_rounded_number_2: QIcon
    square_rounded_number_2_filled: QIcon
    square_rounded_number_3: QIcon
    square_rounded_number_3_filled: QIcon
    square_rounded_number_4: QIcon
    square_rounded_number_4_filled: QIcon
    square_rounded_number_5: QIcon
    square_rounded_number_5_filled: QIcon
    square_rounded_number_6: QIcon
    square_rounded_number_6_filled: QIcon
    square_rounded_number_7: QIcon
    square_rounded_number_7_filled: QIcon
    square_rounded_number_8: QIcon
    square_rounded_number_8_filled: QIcon
    square_rounded_number_9: QIcon
    square_rounded_number_9_filled: QIcon
    square_rounded_plus: QIcon
    square_rounded_plus_2: QIcon
    square_rounded_plus_filled: QIcon
    square_rounded_x: QIcon
    square_rounded_x_filled: QIcon
    squares_diagonal: QIcon
    squares_filled: QIcon
    square_toggle: QIcon
    square_toggle_horizontal: QIcon
    square_x: QIcon
    square_x_filled: QIcon
    stack: QIcon
    stack_2: QIcon
    stack_3: QIcon
    stack_pop: QIcon
    stack_push: QIcon
    stairs: QIcon
    stairs_down: QIcon
    stairs_up: QIcon
    star: QIcon
    star_filled: QIcon
    star_half: QIcon
    star_half_filled: QIcon
    star_off: QIcon
    stars: QIcon
    stars_filled: QIcon
    stars_off: QIcon
    status_change: QIcon
    steam: QIcon
    steering_wheel: QIcon
    steering_wheel_off: QIcon
    step_into: QIcon
    step_out: QIcon
    stereo_glasses: QIcon
    stethoscope: QIcon
    stethoscope_off: QIcon
    sticker: QIcon
    storm: QIcon
    storm_off: QIcon
    stretching: QIcon
    stretching_2: QIcon
    strikethrough: QIcon
    s_turn_down: QIcon
    s_turn_left: QIcon
    s_turn_right: QIcon
    s_turn_up: QIcon
    submarine: QIcon
    subscript: QIcon
    subtask: QIcon
    sum: QIcon
    sum_off: QIcon
    sun: QIcon
    sun_filled: QIcon
    sunglasses: QIcon
    sun_high: QIcon
    sun_low: QIcon
    sun_moon: QIcon
    sun_off: QIcon
    sunrise: QIcon
    sunset: QIcon
    sunset_2: QIcon
    sun_wind: QIcon
    superscript: QIcon
    svg: QIcon
    swimming: QIcon
    swipe: QIcon
    switch: QIcon
    switch_2: QIcon
    switch_3: QIcon
    switch_horizontal: QIcon
    switch_vertical: QIcon
    sword: QIcon
    sword_off: QIcon
    swords: QIcon
    table: QIcon
    table_alias: QIcon
    table_column: QIcon
    table_down: QIcon
    table_export: QIcon
    table_filled: QIcon
    table_heart: QIcon
    table_import: QIcon
    table_minus: QIcon
    table_off: QIcon
    table_options: QIcon
    table_plus: QIcon
    table_row: QIcon
    table_share: QIcon
    table_shortcut: QIcon
    tag: QIcon
    tag_off: QIcon
    tags: QIcon
    tags_off: QIcon
    tag_starred: QIcon
    tallymark_1: QIcon
    tallymark_2: QIcon
    tallymark_3: QIcon
    tallymark_4: QIcon
    tallymarks: QIcon
    tank: QIcon
    target: QIcon
    target_arrow: QIcon
    target_off: QIcon
    teapot: QIcon
    telescope: QIcon
    telescope_off: QIcon
    temperature: QIcon
    temperature_celsius: QIcon
    temperature_fahrenheit: QIcon
    temperature_minus: QIcon
    temperature_off: QIcon
    temperature_plus: QIcon
    template: QIcon
    template_off: QIcon
    tent: QIcon
    tent_off: QIcon
    terminal: QIcon
    terminal_2: QIcon
    test_pipe: QIcon
    test_pipe_2: QIcon
    test_pipe_off: QIcon
    tex: QIcon
    text_caption: QIcon
    text_color: QIcon
    text_decrease: QIcon
    text_direction_ltr: QIcon
    text_direction_rtl: QIcon
    text_increase: QIcon
    text_orientation: QIcon
    text_plus: QIcon
    text_recognition: QIcon
    text_resize: QIcon
    text_size: QIcon
    text_spellcheck: QIcon
    texture: QIcon
    text_wrap: QIcon
    text_wrap_disabled: QIcon
    theater: QIcon
    thermometer: QIcon
    thumb_down: QIcon
    thumb_down_filled: QIcon
    thumb_down_off: QIcon
    thumb_up: QIcon
    thumb_up_filled: QIcon
    thumb_up_off: QIcon
    ticket: QIcon
    ticket_off: QIcon
    tic_tac: QIcon
    tie: QIcon
    tilde: QIcon
    tilt_shift: QIcon
    tilt_shift_off: QIcon
    time_duration_0: QIcon
    time_duration_10: QIcon
    time_duration_15: QIcon
    time_duration_30: QIcon
    time_duration_45: QIcon
    time_duration_5: QIcon
    time_duration_60: QIcon
    time_duration_90: QIcon
    time_duration_off: QIcon
    timeline: QIcon
    timeline_event: QIcon
    timeline_event_exclamation: QIcon
    timeline_event_minus: QIcon
    timeline_event_plus: QIcon
    timeline_event_text: QIcon
    timeline_event_x: QIcon
    tir: QIcon
    toggle_left: QIcon
    toggle_right: QIcon
    toilet_paper: QIcon
    toilet_paper_off: QIcon
    toml: QIcon
    tool: QIcon
    tools: QIcon
    tools_kitchen: QIcon
    tools_kitchen_2: QIcon
    tools_kitchen_2_off: QIcon
    tools_kitchen_off: QIcon
    tools_off: QIcon
    tooltip: QIcon
    topology_bus: QIcon
    topology_complex: QIcon
    topology_full: QIcon
    topology_full_hierarchy: QIcon
    topology_ring: QIcon
    topology_ring_2: QIcon
    topology_ring_3: QIcon
    topology_star: QIcon
    topology_star_2: QIcon
    topology_star_3: QIcon
    topology_star_ring: QIcon
    topology_star_ring_2: QIcon
    topology_star_ring_3: QIcon
    torii: QIcon
    tornado: QIcon
    tournament: QIcon
    tower: QIcon
    tower_off: QIcon
    track: QIcon
    tractor: QIcon
    trademark: QIcon
    traffic_cone: QIcon
    traffic_cone_off: QIcon
    traffic_lights: QIcon
    traffic_lights_off: QIcon
    train: QIcon
    transfer: QIcon
    transfer_in: QIcon
    transfer_out: QIcon
    transfer_vertical: QIcon
    transform: QIcon
    transform_filled: QIcon
    transition_bottom: QIcon
    transition_left: QIcon
    transition_right: QIcon
    transition_top: QIcon
    trash: QIcon
    trash_filled: QIcon
    trash_off: QIcon
    trash_x: QIcon
    trash_x_filled: QIcon
    treadmill: QIcon
    tree: QIcon
    trees: QIcon
    trekking: QIcon
    trending_down: QIcon
    trending_down_2: QIcon
    trending_down_3: QIcon
    trending_up: QIcon
    trending_up_2: QIcon
    trending_up_3: QIcon
    triangle: QIcon
    triangle_filled: QIcon
    triangle_inverted: QIcon
    triangle_inverted_filled: QIcon
    triangle_minus: QIcon
    triangle_minus_2: QIcon
    triangle_off: QIcon
    triangle_plus: QIcon
    triangle_plus_2: QIcon
    triangles: QIcon
    triangle_square_circle: QIcon
    triangle_square_circle_filled: QIcon
    trident: QIcon
    trolley: QIcon
    trophy: QIcon
    trophy_filled: QIcon
    trophy_off: QIcon
    trowel: QIcon
    truck: QIcon
    truck_delivery: QIcon
    truck_loading: QIcon
    truck_off: QIcon
    truck_return: QIcon
    txt: QIcon
    typography: QIcon
    typography_off: QIcon
    ufo: QIcon
    ufo_off: QIcon
    umbrella: QIcon
    umbrella_filled: QIcon
    umbrella_off: QIcon
    underline: QIcon
    unlink: QIcon
    upload: QIcon
    urgent: QIcon
    usb: QIcon
    user: QIcon
    user_bolt: QIcon
    user_cancel: QIcon
    user_check: QIcon
    user_circle: QIcon
    user_code: QIcon
    user_cog: QIcon
    user_dollar: QIcon
    user_down: QIcon
    user_edit: QIcon
    user_exclamation: QIcon
    user_heart: QIcon
    user_hexagon: QIcon
    user_minus: QIcon
    user_off: QIcon
    user_pause: QIcon
    user_pentagon: QIcon
    user_pin: QIcon
    user_plus: QIcon
    user_question: QIcon
    users: QIcon
    user_search: QIcon
    users_group: QIcon
    user_share: QIcon
    user_shield: QIcon
    users_minus: QIcon
    users_plus: QIcon
    user_square: QIcon
    user_square_rounded: QIcon
    user_star: QIcon
    user_up: QIcon
    user_x: QIcon
    uv_index: QIcon
    ux_circle: QIcon
    vaccine: QIcon
    vaccine_bottle: QIcon
    vaccine_bottle_off: QIcon
    vaccine_off: QIcon
    vacuum_cleaner: QIcon
    variable: QIcon
    variable_minus: QIcon
    variable_off: QIcon
    variable_plus: QIcon
    vector: QIcon
    vector_bezier: QIcon
    vector_bezier_2: QIcon
    vector_bezier_arc: QIcon
    vector_bezier_circle: QIcon
    vector_off: QIcon
    vector_spline: QIcon
    vector_triangle: QIcon
    vector_triangle_off: QIcon
    venus: QIcon
    versions: QIcon
    versions_filled: QIcon
    versions_off: QIcon
    video: QIcon
    video_minus: QIcon
    video_off: QIcon
    video_plus: QIcon
    view_360: QIcon
    view_360_off: QIcon
    viewfinder: QIcon
    viewfinder_off: QIcon
    viewport_narrow: QIcon
    viewport_wide: QIcon
    vinyl: QIcon
    vip: QIcon
    vip_off: QIcon
    virus: QIcon
    virus_off: QIcon
    virus_search: QIcon
    vocabulary: QIcon
    vocabulary_off: QIcon
    volcano: QIcon
    volume: QIcon
    volume_2: QIcon
    volume_3: QIcon
    volume_off: QIcon
    vs: QIcon
    walk: QIcon
    wall: QIcon
    wallet: QIcon
    wallet_off: QIcon
    wall_off: QIcon
    wallpaper: QIcon
    wallpaper_off: QIcon
    wand: QIcon
    wand_off: QIcon
    wash: QIcon
    wash_dry: QIcon
    wash_dry_1: QIcon
    wash_dry_2: QIcon
    wash_dry_3: QIcon
    wash_dry_a: QIcon
    wash_dryclean: QIcon
    wash_dryclean_off: QIcon
    wash_dry_dip: QIcon
    wash_dry_f: QIcon
    wash_dry_flat: QIcon
    wash_dry_hang: QIcon
    wash_dry_off: QIcon
    wash_dry_p: QIcon
    wash_dry_shade: QIcon
    wash_dry_w: QIcon
    wash_eco: QIcon
    wash_gentle: QIcon
    wash_hand: QIcon
    wash_machine: QIcon
    wash_off: QIcon
    wash_press: QIcon
    wash_temperature_1: QIcon
    wash_temperature_2: QIcon
    wash_temperature_3: QIcon
    wash_temperature_4: QIcon
    wash_temperature_5: QIcon
    wash_temperature_6: QIcon
    wash_tumble_dry: QIcon
    wash_tumble_off: QIcon
    waterpolo: QIcon
    wave_saw_tool: QIcon
    wave_sine: QIcon
    wave_square: QIcon
    webhook: QIcon
    webhook_off: QIcon
    weight: QIcon
    wheel: QIcon
    wheelchair: QIcon
    wheelchair_off: QIcon
    whirl: QIcon
    wifi: QIcon
    wifi_0: QIcon
    wifi_1: QIcon
    wifi_2: QIcon
    wifi_off: QIcon
    wind: QIcon
    windmill: QIcon
    windmill_filled: QIcon
    windmill_off: QIcon
    wind_off: QIcon
    window: QIcon
    window_maximize: QIcon
    window_minimize: QIcon
    window_off: QIcon
    windsock: QIcon
    wiper: QIcon
    wiper_wash: QIcon
    woman: QIcon
    wood: QIcon
    world: QIcon
    world_bolt: QIcon
    world_cancel: QIcon
    world_check: QIcon
    world_code: QIcon
    world_cog: QIcon
    world_dollar: QIcon
    world_down: QIcon
    world_download: QIcon
    world_exclamation: QIcon
    world_heart: QIcon
    world_latitude: QIcon
    world_longitude: QIcon
    world_minus: QIcon
    world_off: QIcon
    world_pause: QIcon
    world_pin: QIcon
    world_plus: QIcon
    world_question: QIcon
    world_search: QIcon
    world_share: QIcon
    world_star: QIcon
    world_up: QIcon
    world_upload: QIcon
    world_www: QIcon
    world_x: QIcon
    wrecking_ball: QIcon
    writing: QIcon
    writing_off: QIcon
    writing_sign: QIcon
    writing_sign_off: QIcon
    x: QIcon
    xbox_a: QIcon
    xbox_b: QIcon
    xbox_x: QIcon
    xbox_y: QIcon
    xd: QIcon
    xxx: QIcon
    yin_yang: QIcon
    yin_yang_filled: QIcon
    yoga: QIcon
    zeppelin: QIcon
    zeppelin_off: QIcon
    zip: QIcon
    zodiac_aquarius: QIcon
    zodiac_aries: QIcon
    zodiac_cancer: QIcon
    zodiac_capricorn: QIcon
    zodiac_gemini: QIcon
    zodiac_leo: QIcon
    zodiac_libra: QIcon
    zodiac_pisces: QIcon
    zodiac_sagittarius: QIcon
    zodiac_scorpio: QIcon
    zodiac_taurus: QIcon
    zodiac_virgo: QIcon
    zoom_cancel: QIcon
    zoom_check: QIcon
    zoom_check_filled: QIcon
    zoom_code: QIcon
    zoom_exclamation: QIcon
    zoom_filled: QIcon
    zoom_in: QIcon
    zoom_in_area: QIcon
    zoom_in_area_filled: QIcon
    zoom_in_filled: QIcon
    zoom_money: QIcon
    zoom_out: QIcon
    zoom_out_area: QIcon
    zoom_out_filled: QIcon
    zoom_pan: QIcon
    zoom_question: QIcon
    zoom_replace: QIcon
    zoom_reset: QIcon
    zzz: QIcon
    zzz_off: QIcon
